'use strict';

var lr = require('@lezer/lr');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');
var autocomplete = require('@codemirror/autocomplete');

// Note that 'eval' and 'do' are not in this list as they can accept a block.
const namedUnaryOperators = [
    'abs',
    'alarm',
    'await',
    'caller',
    'chdir',
    'chr',
    'chroot',
    'close',
    'closedir',
    'cos',
    'defined',
    'delete',
    'eof',
    'evalbytes',
    'exists',
    'exit',
    'exp',
    'fileno',
    'getc',
    'gethostbyname',
    'getnetbyname',
    'getpgrp',
    'getprotobyname',
    'glob',
    'gmtime',
    'hex',
    'int',
    'lc',
    'lcfirst',
    'length',
    'localtime',
    'lock',
    'log',
    'lstat',
    'oct',
    'ord',
    'pos',
    'quotemeta',
    'rand',
    'readdir',
    'readline',
    'readlink',
    'readpipe',
    'reset',
    'rewinddir',
    'ref',
    'rmdir',
    'scalar',
    'select',
    'sin',
    'sleep',
    'sqrt',
    'srand',
    'stat',
    'tell',
    'telldir',
    'tied',
    'uc',
    'ucfirst',
    'umask',
    'undef',
    'untie'
];
// The list operators that can operate on a block (grep, map, join, sort, and unpack) are handled separately.
const listOperators = [
    'atan2',
    'chomp',
    'chop',
    'chmod',
    'chown',
    'crypt',
    'die',
    'fcntl',
    'flock',
    'getpriority',
    'index',
    'ioctl',
    'kill',
    'link',
    'mkdir',
    'open',
    'opendir',
    'pack',
    'pipe',
    'read',
    'rename',
    'reverse',
    'rindex',
    'seek',
    'seekdir',
    'setpgrp',
    'setpriority',
    'split',
    'sprintf',
    'substr',
    'symlink',
    'syscall',
    'sysopen',
    'sysread',
    'sysseek',
    'syswrite',
    'tie',
    'truncate',
    'unlink',
    'utime',
    'vec',
    'waitpid',
    'warn'
];

// This file was generated by lezer-generator. You probably shouldn't edit it.
const automaticSemicolon = 309, statementEnd = 310, UnrestrictedIdentifier = 1, SpecialScalarVariable = 2, NamedUnaryOperator = 3, ListOperator = 4, FileTestOp = 5, IOOperatorStart = 6, Glob = 7, ReadonlySTDIN = 8, IOOperatorEnd = 9, HeredocStartIdentifier = 10, uninterpolatedHeredocStart = 311, interpolatedHeredocStart = 312, HeredocEndIdentifier = 11, InterpolatedStringContent = 12, EscapeSequence = 13, afterInterpolation = 313, packageNamePart = 314, afterPackageName = 315, QuoteLikeStartDelimiter = 14, QuoteLikeSeparatorDelimiter = 15, QuoteLikeEndDelimiter = 16, StringContent = 17, QWElement = 18, patternMatchStart = 316, RegexOptions = 19, regexEnd = 317, PodDirective = 20, PodContent = 21, PodCut = 22, endDataBlock = 318, q = 42, qq = 45, qw = 71, qx = 82, m = 84, qr = 88, s = 90, tr = 92, y = 93, Prototype = 111, PackageName = 121;

const isUpperCaseASCIILetter = (ch) => ch >= 65 && ch <= 90;
const isLowerCaseASCIILetter = (ch) => ch >= 97 && ch <= 122;
const isASCIILetter = (ch) => isLowerCaseASCIILetter(ch) || isUpperCaseASCIILetter(ch);
const isDigit = (ch) => ch >= 48 && ch <= 55;
const isIdentifierChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch) || isDigit(ch);
const isVariableStartChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch);
const isRegexOptionChar = (ch, regexType) => {
    if (regexType === tr || regexType === y) {
        if (ch == 99 /* c */ || ch == 100 /* d */ || ch == 115 /* s */ || ch == 114 /* r */)
            return true;
        return false;
    }
    if (ch == 109 /* m */ ||
        ch == 115 /* s */ ||
        ch == 105 /* i */ ||
        ch == 120 /* x */ ||
        ch == 112 /* p */ ||
        ch == 111 /* o */ ||
        ch == 100 /* d */ ||
        ch == 117 /* u */ ||
        ch == 97 /* a */ ||
        ch == 108 /* l */ ||
        ch == 110 /* n */)
        return true;
    if ((regexType === m || regexType === s) && (ch == 103 /* g */ || ch == 99) /* c */)
        return true;
    if (regexType == s && (ch == 101 /* e */ || ch == 114) /* r */)
        return true;
    return false;
};
// !"$%&'()*+,-./0123456789:;<=>?@[\]`~
// For arrays this is only used for interpolation and in that case only @$, @+, @-, and @1 .. @9 are allowed.
const isSpecialVariableChar = (ch, arrayType = false) => arrayType
    ? ch == 36 || ch == 43 || ch == 45 || (ch >= 49 && ch <= 57)
    : (ch >= 33 && ch != 35 && ch <= 64) || ch == 91 || ch == 92 || ch == 93 || ch == 96 || ch == 126;
/* 0-9, a-f, A-F */
const isHex = (ch) => (ch >= 48 && ch <= 55) || (ch >= 97 && ch <= 102) || (ch >= 65 && ch <= 70);
// ' ', \t, \n, \r
const isWhitespace = (ch) => ch == 32 || ch == 9 || ch == 10 || ch == 13;
const gobbleWhitespace = (input) => {
    while (isWhitespace(input.next))
        input.advance();
};
// rwxoRWXOezsfdlpSbctugkTBMAC
const isFileTestOperatorChar = (ch) => ch == 114 ||
    ch == 119 ||
    ch == 120 ||
    ch == 111 ||
    ch == 82 ||
    ch == 87 ||
    ch == 88 ||
    ch == 79 ||
    ch == 101 ||
    ch == 122 ||
    ch == 115 ||
    ch == 102 ||
    ch == 100 ||
    ch == 108 ||
    ch == 112 ||
    ch == 83 ||
    ch == 98 ||
    ch == 99 ||
    ch == 116 ||
    ch == 117 ||
    ch == 103 ||
    ch == 107 ||
    ch == 84 ||
    ch == 66 ||
    ch == 77 ||
    ch == 65 ||
    ch == 67;
const heredocQueue = [];
// Base class that all tracker contexts extend.
class Context {
    type;
    parent;
    stackPos;
    // Used by quote and quoteLike operators.
    startDelimiter;
    endDelimiter;
    // Used by quoteLike operators.
    quoteLikeType;
    nestLevel = 0;
    // Used by heredocs.
    tag;
    indented = false;
    inBody = false;
    newlinePos;
    // Used by any interpolating context.
    interpolating = false;
    constructor(type, parent = null, stackPos = -1, options = {}) {
        this.type = type;
        this.parent = parent;
        this.stackPos = stackPos;
        this.quoteLikeType = options.quoteLikeType;
        this.interpolating = options.interpolating ?? true;
        this.indented = options.indented ?? false;
        if (options.tag)
            this.tag = options.tag;
        if (typeof options.startDelimiter === 'number')
            this.setStartAndEndDelimiters(options.startDelimiter);
        if (typeof options.newlinePos === 'number')
            this.newlinePos = options.newlinePos;
    }
    setStartAndEndDelimiters(start) {
        this.startDelimiter = start;
        if (start == 40 /* ( */) {
            this.endDelimiter = 41 /* ) */;
        }
        else if (start == 60 /* < */) {
            this.endDelimiter = 62 /* > */;
        }
        else if (start == 91 /* [ */) {
            this.endDelimiter = 93 /* ] */;
        }
        else if (start == 123 /* { */) {
            this.endDelimiter = 125 /* } */;
        }
        else
            this.endDelimiter = start;
    }
    atEnd(input) {
        if (this.type === 'heredoc') {
            if (!this.tag || input.peek(-1) !== 10)
                return false;
            let pos = 0;
            if (this.indented) {
                let nextChar = input.peek(pos);
                while (isWhitespace(nextChar))
                    nextChar = input.peek(++pos);
            }
            for (const tagCh of this.tag) {
                if (input.peek(pos++) !== tagCh)
                    return false;
            }
            if (input.peek(pos) < 0 || input.peek(pos) == 10)
                return pos;
            return false;
        }
        else {
            return input.next === this.endDelimiter ? 1 : false;
        }
    }
}
const contextTracker = new lr.ContextTracker({
    start: new Context('root'),
    shift(context, term, stack, input) {
        if (term === q || term === qq || term === qx || term === qw) {
            return new Context('quoteLike', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === m || term === qr || term === s || term === tr || term === y) {
            return new Context('quoteLike&regex', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === IOOperatorStart) {
            return new Context('iooperator', context);
        }
        else if (term === HeredocStartIdentifier) {
            let pos = 0;
            const indented = input.next == 126; /* ~ */
            if (indented)
                ++pos;
            let haveWhitespace = false;
            while (isWhitespace(input.peek(pos))) {
                haveWhitespace = true;
                ++pos;
            }
            const quote = input.peek(pos) == 39 /* ' */ || input.peek(pos) == 34 /* " */ || input.peek(pos) == 96 /* ` */
                ? input.peek(pos)
                : undefined;
            if (!quote && haveWhitespace)
                return context;
            if (quote)
                ++pos;
            const backslashedTag = !quote && input.peek(pos) == 92; /* \\ */
            if (backslashedTag && (haveWhitespace || isWhitespace(input.peek(++pos))))
                return context;
            if (!isIdentifierChar(input.peek(pos)))
                return context;
            const tag = [input.peek(pos++)];
            for (;;) {
                const next = input.peek(pos++);
                if (!isIdentifierChar(next))
                    break;
                tag.push(next);
            }
            if (heredocQueue[0]?.stackPos !== stack.pos) {
                while (input.peek(pos) != 10 /* \n */ && input.peek(pos) >= 0)
                    ++pos;
                heredocQueue.unshift(new Context('heredoc', context, stack.pos, {
                    tag,
                    interpolating: (!quote || quote == 34 || quote == 96) && !backslashedTag,
                    indented,
                    newlinePos: input.pos + pos
                }));
            }
            return context;
        }
        else if (term === patternMatchStart) {
            if (input.next == 47 /* / */)
                return new Context('regex', context, stack.pos, { startDelimiter: 47, quoteLikeType: m });
        }
        else if ((context.type !== 'quote' || input.next != context.endDelimiter) &&
            term !== InterpolatedStringContent) {
            if (input.next == 34 /* " */ || input.next == 96 /* ` */) {
                return new Context('quote', context, stack.pos, { startDelimiter: input.next });
            }
        }
        if (context.type.startsWith('quoteLike') && term === QuoteLikeStartDelimiter) {
            let pos = 1;
            let startDelimiter = input.next;
            while (isWhitespace(startDelimiter))
                startDelimiter = input.peek(pos++);
            if (startDelimiter >= 0) {
                context.setStartAndEndDelimiters(startDelimiter);
                // Note that q and qw are not interpolated, but don't need to set this because they can't accept
                // interpolated content.
                if (context.quoteLikeType === tr ||
                    context.quoteLikeType === y ||
                    ((context.quoteLikeType === m ||
                        context.quoteLikeType === qr ||
                        context.quoteLikeType === qx ||
                        context.quoteLikeType === s) &&
                        startDelimiter == 39) /* ' */)
                    context.interpolating = false;
                return context;
            }
        }
        if ((term === interpolatedHeredocStart || term === uninterpolatedHeredocStart) &&
            heredocQueue.slice(-1)[0]?.newlinePos !== context.newlinePos) {
            const heredocContext = heredocQueue.pop();
            if (heredocContext) {
                heredocContext.parent = context;
                heredocContext.inBody = true;
                return heredocContext;
            }
        }
        if (context.parent &&
            ((context.type === 'quote' && input.next === context.endDelimiter) ||
                (context.type === 'quoteLike' && term === QuoteLikeEndDelimiter) ||
                (context.type === 'regex' && term === regexEnd) ||
                (context.type === 'quoteLike&regex' && term === regexEnd) ||
                (context.type === 'heredoc' && term === HeredocEndIdentifier) ||
                (context.type === 'iooperator' && term === IOOperatorEnd))) {
            return context.parent;
        }
        return context;
    },
    strict: false
});
const semicolon = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(statementEnd) &&
        !heredocQueue.length &&
        (input.peek(-1) == 59 /* ; */ ||
            (input.peek(-1) != 59 /* ; */ && (input.next < 0 || input.next == 10))) /* \n */) {
        input.acceptToken(statementEnd, 0);
    }
    else if (stack.canShift(automaticSemicolon) &&
        input.next != 59 /* ; */ &&
        (input.next < 0 || input.next == 125) /* } */)
        input.acceptToken(automaticSemicolon);
});
const unrestrictedIdentifier = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(UnrestrictedIdentifier)) {
        gobbleWhitespace(input);
        if (input.next < 0 || isASCIILetter(input.next) || input.next == 95 /* _ */)
            return;
        while (input.next >= 0 && isIdentifierChar(input.next))
            input.advance();
        input.acceptToken(UnrestrictedIdentifier);
    }
});
// Note that is only to pick up special variables that won't be considered as a ScalarVariable already.
const specialScalarVariable = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(SpecialScalarVariable) && input.next == 36 /* $ */) {
        if (stack.canShift(Prototype))
            return;
        const first = input.peek(1);
        const second = input.peek(2);
        if (first == 123 /* { */ && isSpecialVariableChar(second) && input.peek(3) == 125 /* } */) {
            input.acceptToken(SpecialScalarVariable, 4);
            return;
        }
        if (first == 123 /* { */ && second == 94 /* ^ */) {
            let pos = 3, ch;
            while ((isUpperCaseASCIILetter((ch = input.peek(pos))) || ch == 95) /* _ */ && ch != 125 /* } */)
                ++pos;
            if (ch == 125) {
                input.acceptToken(SpecialScalarVariable, pos + 1);
                return;
            }
        }
        if (first == 94 /* ^ */ && (isUpperCaseASCIILetter(second) || second == 95) /* _ */) {
            input.acceptToken(SpecialScalarVariable, 3);
            return;
        }
        if (!isSpecialVariableChar(first))
            return;
        if (first == 36 /* $ */ && isIdentifierChar(second))
            return;
        input.acceptToken(SpecialScalarVariable, 2);
        return;
    }
});
// Finds the longest lower case word coming up in the stream.  Returns an array
// containing the word and the ascii character code of the next character after it.
const peekLCWord = (input) => {
    let pos = 0;
    let word = '', nextChar;
    while (isLowerCaseASCIILetter((nextChar = input.peek(pos)))) {
        ++pos;
        word += String.fromCharCode(nextChar);
    }
    return [word, nextChar];
};
const builtinOperator = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(NamedUnaryOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (namedUnaryOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(NamedUnaryOperator, word.length);
    }
    if (stack.canShift(ListOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (listOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(ListOperator, word.length);
    }
});
const fileIO = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(FileTestOp) && !stack.canShift(PackageName)) {
        gobbleWhitespace(input);
        if (input.next == 45 /* - */ && isFileTestOperatorChar(input.peek(1)) && !isASCIILetter(input.peek(2)))
            input.acceptToken(FileTestOp, 2);
    }
    // Start an IO operator if the following input contains a '<' character that is not followed by another
    // one or the following input specifically contains <<>>.
    if (stack.canShift(IOOperatorStart) &&
        input.next == 60 &&
        (input.peek(1) != 60 || (input.peek(2) == 62 && input.peek(3) == 62))) {
        input.acceptToken(IOOperatorStart, 1);
        return;
    }
    if (!(stack.context instanceof Context) || stack.context.type !== 'iooperator')
        return;
    // End the IO operator when the '>' character is encountered.
    if (stack.canShift(IOOperatorEnd) && input.next == 62) {
        input.acceptToken(IOOperatorEnd, 1);
        return;
    }
    // In this case the initial '<' started the IO operator, and what follows is '<>>'
    // to finish the read only standard input declaration.
    if (input.peek(0) == 60 && input.peek(1) == 62 && input.peek(2) == 62) {
        input.acceptToken(ReadonlySTDIN, 2);
        return;
    }
    let pos = 0, ch;
    const isPossibleVariable = input.next == 36; /* $ */
    if (isPossibleVariable)
        ++pos;
    let haveWhitespace = false, haveNonASCII = false;
    while ((ch = input.peek(pos)) >= 0 && ch != 62 /* > */) {
        if (isWhitespace(ch))
            haveWhitespace = true;
        if (!isASCIILetter(ch))
            haveNonASCII = true;
        ++pos;
    }
    if ((isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        (!isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        ch < 0)
        return;
    input.acceptToken(Glob, pos);
}, { contextual: true });
const heredoc = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(HeredocStartIdentifier)) {
        const indented = input.next == 126; /* ~ */
        if (indented)
            input.advance();
        gobbleWhitespace(input);
        const quote = input.next == 39 /* ' */ || input.next == 34 /* " */ || input.next == 96 /* ` */
            ? input.next
            : undefined;
        if (!quote && isWhitespace(input.peek(-1)))
            return;
        if (quote)
            input.advance();
        if (input.next == 92 /* \\ */ && (isWhitespace(input.peek(-1)) || isWhitespace(input.advance())))
            return;
        if (!isIdentifierChar(input.next))
            return;
        for (;;) {
            input.advance();
            if (!isIdentifierChar(input.next))
                break;
        }
        if (quote) {
            if (input.next != quote)
                return;
            input.advance();
        }
        input.acceptToken(HeredocStartIdentifier);
        return;
    }
    if (!(stack.context instanceof Context))
        return;
    if (input.next == 10 /* \n */ &&
        heredocQueue.length &&
        heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos &&
        (stack.canShift(uninterpolatedHeredocStart) || stack.canShift(interpolatedHeredocStart))) {
        if (heredocQueue.slice(-1)[0]?.interpolating)
            input.acceptToken(interpolatedHeredocStart, 1);
        else
            input.acceptToken(uninterpolatedHeredocStart, 1);
        return;
    }
    if (stack.context.type !== 'heredoc' || !stack.context.inBody)
        return;
    if (stack.context.interpolating) {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        else if (input.next < 0) {
            input.acceptToken(HeredocEndIdentifier);
            return;
        }
    }
    else {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        for (;;) {
            if (input.next < 0) {
                input.acceptToken(HeredocEndIdentifier);
                return;
            }
            if (input.next != 10 /* \n */) {
                input.advance();
                continue;
            }
            input.advance();
            const endCount = stack.context.atEnd(input);
            if (endCount) {
                input.acceptToken(StringContent);
                return;
            }
            input.advance();
        }
    }
}, { contextual: true });
const scanEscape = (input) => {
    const after = input.peek(1);
    // Restricted range octal character
    if (after >= 48 && after <= 55 /* 0-7 */) {
        let size = 2, next;
        while (size < 5 && (next = input.peek(size)) >= 48 && next <= 55)
            ++size;
        return size;
    }
    // Restricted range hexidecimal character
    if (after == 120 /* x */ && isHex(input.peek(2)))
        return isHex(input.peek(3)) ? 4 : 3;
    // Hexidecimal character
    if (after == 120 /* x */ && input.peek(2) == 123 /* { */) {
        // FIXME: There could be optional blanks at the beginning and end inside the braces.
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (!isHex(next))
                break;
        }
    }
    // This could be any named unicode character or character sequence.
    if (after == 78 /* N */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 0)
                break;
        }
    }
    // Octal character
    if (after == 111 /* o */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 48 || next > 55 /* not 0-7 */)
                break;
        }
    }
    return 2;
};
const interpolated = new lr.ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.interpolating)
        return;
    let content = false;
    for (;; content = true) {
        if (heredocQueue.length &&
            (stack.context.type !== 'heredoc' ||
                heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos) &&
            input.next == 10 /* \n */) {
            break;
        }
        if ((stack.context.nestLevel == 0 && stack.context.atEnd(input)) ||
            input.next < 0 ||
            ((input.next == 36 /* $ */ || input.next == 64) /* @ */ &&
                (isVariableStartChar(input.peek(1)) ||
                    input.peek(1) == 123 /* { */ ||
                    (isSpecialVariableChar(input.peek(1), input.next == 64 /* @ */) &&
                        (stack.context.nestLevel > 0 || input.peek(1) !== stack.context.endDelimiter))))) {
            break;
        }
        if (stack.context.type.startsWith('quoteLike') &&
            stack.context.startDelimiter !== stack.context.endDelimiter &&
            input.next === stack.context.startDelimiter) {
            ++stack.context.nestLevel;
        }
        else if (stack.context.nestLevel > 0 && input.next === stack.context.endDelimiter) {
            --stack.context.nestLevel;
        }
        else if (input.next == 92 /* \\ */) {
            const escaped = scanEscape(input);
            if (escaped) {
                if (content)
                    break;
                else {
                    input.acceptToken(EscapeSequence, escaped);
                    return;
                }
            }
        }
        else if (!content &&
            (input.next == 91 /* [ */ ||
                input.next == 123 /* { */ ||
                (input.next == 45 /* - */ &&
                    input.peek(1) == 62 /* > */ &&
                    (input.peek(2) == 91 /* [ */ || input.peek(2) == 123))) /* { */ &&
            stack.canShift(afterInterpolation)) {
            input.acceptToken(afterInterpolation);
            return;
        }
        else if (!content &&
            input.next == 58 /* : */ &&
            input.peek(1) == 58 &&
            (stack.canShift(packageNamePart) || stack.canShift(afterPackageName))) {
            let pos = 2, ch;
            while (isIdentifierChar((ch = input.peek(pos))))
                ++pos;
            if (ch == 58 && input.peek(pos + 1) == 58)
                input.acceptToken(packageNamePart);
            else
                input.acceptToken(afterPackageName);
            return;
        }
        input.advance();
    }
    if (content)
        input.acceptToken(InterpolatedStringContent);
}, { contextual: true });
// Note that the paired delimiters enabled by the extra_paired_delimiters
// feature are not dealt with by the quote-like tokenizers.
const quoteLikeOperator = new lr.ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.type.startsWith('quoteLike'))
        return;
    if (!stack.context.startDelimiter) {
        const haveWhitespace = isWhitespace(input.next);
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (stack.canShift(QuoteLikeStartDelimiter) && nextChar >= 0 && (!haveWhitespace || nextChar !== 35)) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
        return;
    }
    if (stack.canShift(QWElement) && isWhitespace(input.next))
        gobbleWhitespace(input);
    if (stack.canShift(QuoteLikeSeparatorDelimiter) &&
        stack.context.startDelimiter === stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeSeparatorDelimiter, 1);
        return;
    }
    else if (stack.canShift(QuoteLikeEndDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (stack.canShift(QuoteLikeStartDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter) {
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (nextChar === stack.context.startDelimiter) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
    }
    if (input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (input.next >= 0) {
        if (stack.canShift(StringContent)) {
            while (input.next >= 0 &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(StringContent);
            return;
        }
        else if (stack.canShift(QWElement)) {
            while (input.next >= 0 &&
                !isWhitespace(input.next) &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(QWElement);
            return;
        }
    }
}, { contextual: true });
const regex = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(patternMatchStart) && input.next == 47 /* / */) {
        const divisionToken = stack.parser.nodeSet.types.find((t) => t.name == '/')?.id;
        if (typeof divisionToken === 'number' && !stack.canShift(divisionToken))
            input.acceptToken(patternMatchStart);
    }
    if (!(stack.context instanceof Context) || !stack.context.type.endsWith('regex'))
        return;
    if (stack.canShift(RegexOptions) &&
        stack.context.quoteLikeType &&
        isRegexOptionChar(input.next, stack.context.quoteLikeType)) {
        while (input.next >= 0 && isRegexOptionChar(input.next, stack.context.quoteLikeType))
            input.advance();
        input.acceptToken(RegexOptions);
        return;
    }
    if (stack.canShift(regexEnd)) {
        input.acceptToken(regexEnd);
        return;
    }
}, { contextual: true });
const pod = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(PodDirective)) {
        if ((input.peek(-1) == 10 /* \n */ || input.peek(-1) < 0) &&
            input.next == 61 /* = */ &&
            isASCIILetter(input.peek(1))) {
            while (input.next >= 0 && input.next != 10)
                input.advance();
            input.acceptToken(PodDirective);
            return;
        }
    }
    if (stack.canShift(PodContent)) {
        while (input.next >= 0) {
            if (input.next != 10) {
                input.advance();
                continue;
            }
            input.advance();
            if (input.peek(0) == 61 /* = */ &&
                input.peek(1) == 99 /* c */ &&
                input.peek(2) == 117 /* u */ &&
                input.peek(3) == 116 /* t */ &&
                (input.peek(4) == 10 || input.peek(4) < 0))
                break;
        }
        input.acceptToken(PodContent);
        return;
    }
    if (stack.canShift(PodCut)) {
        if ((input.peek(-1) == 10 || input.peek(-1) < 0) &&
            input.peek(0) == 61 /* = */ &&
            input.peek(1) == 99 /* c */ &&
            input.peek(2) == 117 /* u */ &&
            input.peek(3) == 116 /* t */ &&
            (input.peek(4) == 10 || input.peek(4) < 0)) {
            input.acceptToken(PodCut, 4);
            return;
        }
    }
});
const endData = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(endDataBlock)) {
        while (input.advance() >= 0)
            ;
        input.acceptToken(endDataBlock);
    }
});

// This file was generated by lezer-generator. You probably shouldn't edit it.
const spec_Identifier = {__proto__:null,q:85, qq:91, __FILE__:125, __LINE__:127, __PACKAGE__:129, __SUB__:131, qw:143, qx:165, m:169, qr:177, s:181, tr:185, y:187, our:209, state:211, my:213, local:215, sub:219, prototype:235, package:241, use:253, no:255, if:263, lib:267, subs:271, feature:275, require:281, constant:285, parent:289, base:291, async:299, return:307, unless:309, while:311, until:313, for:315, foreach:317, elsif:323, else:327, continue:337, BEGIN:355, UNITCHECK:357, CHECK:359, INIT:361, END:363, __END__:373, __DATA__:375, next:379, last:381, redo:383, x:393, lt:407, gt:409, le:411, ge:413, eq:417, ne:419, cmp:423, isa:425, and:437, or:439, xor:441, not:449, fork:457, getpid:459, time:461, times:463, wait:465, wantarray:467, grep:473, map:475, join:477, sort:479, unpack:481, bless:493, print:497, say:499, printf:501, STDIN:503, STDERR:505, STDOUT:507, exec:511, system:513, SUPER:517, eval:885, do:541, goto:545, push:553, unshift:555, splice:557, pop:561, shift:563, each:567, values:569, keys:571};
const parser = lr.LRParser.deserialize({
  version: 14,
  states: "#JQQ`Q!1hOOP(QOpOOO(YQ!LsO'#J[OOQq'#J['#J[OOO#t'#J_'#J_O+nO!!^O'#DVO,hO! pO'#DXOOO#t'#Jb'#JbO,oO!!^O'#DYO,wQ!LsO'#J^OOQ'y'#J^'#J^O0nQ!LsO'#DeO3xQNYO'#DdOOQq'#Je'#JeO3}OpO'#DiOOQ'y'#Jf'#JfOOQq'#Jg'#JgOOQq'#Jh'#JhOOQq'#Ji'#JiOOQq'#Jj'#JjOOQq'#Dk'#DkO4SQ!LsO'#DkO?bQ#${O'#EfOBeQ!LsO'#JdOCRQ!&bO'#DrOOO#t'#Jn'#JnOHbO!!^O'#DtOOQq'#Jk'#JkOHjQNYO'#DwOHuQ!&bO'#DyONUQ!1hO'#EvO!%oQ!&bO'#HRO!%vQ!LsO'#KeO!({O! pO'#EOOOO#t'#Jp'#JpO!)SO!!^O'#EPOOO#t'#Jq'#JqO!)[O!!^O'#ERO!)dOMhO'#ETOOO#t'#Jr'#JrO!)iO!!^O'#EVOOO#t'#Js'#JsO!)qO!!^O'#EXOOO#t'#Ju'#JuOOO#t'#Jv'#JvO!)yO!!^O'#EZO!*RQNYO'#E^O!*^QNYO'#E`O!*iQNYO'#EbO!*wQNYO'#EdOOQt'#Jx'#JxOOQt'#Jy'#JyOOQt'#Jz'#JzOOQt'#J{'#J{OOQt'#Jw'#JwO!+hQN^O'#EgOOQp'#KO'#KOOOQp'#KR'#KRO!+oQNYO'#EwOOQp'#KT'#KTOOQp'#KU'#KUO!,YQ$ItO'#E}O!+tQ$ItO'#E}OOQ'x'#KX'#KXOOQp'#K^'#K^O!,jQNYO'#F]O!,oQNZO'#KdO!,}QNZO'#FeOOQp'#Kf'#KfO!-hQNYO'#ElO!-xQNYO'#FfOOQ'y'#Kg'#KgO!3ZQ!&cO'#FjOOQ'x'#Kj'#KjOOQ'x'#Kk'#KkOOQ'x'#Kl'#KlOOQ'x'#Km'#KmOOQ'x'#Kn'#KnO!3wQNYO'#FiO!4]QNYO'#FqO!4]QNYO'#FvO!4]QNYO'#FwO!4bQNYO'#GPO!4]QNYO'#F{O!4sQ$ItO'#F}O!5[Q!1iO'#GPO!<fQNZO'#GRO!,}QNZO'#GQOOQp'#Kr'#KrOOQp'#Ks'#KsOOQp'#Kt'#KtOOQp'#Ku'#KuOOQp'#Kv'#KvO!<qQNYO'#GSOOQ3O'#GY'#GYOOQ3O'#GZ'#GZO!<vO,UO'#G[OOQ7|'#Kx'#KxOOQ7|'#Ky'#KyO!<{Q!6fO'#G]OOQ3O'#KQ'#KQOOQ'x'#L['#L[O!=QQ!&bO'#HRO!=QQ!&bO'#HRO!=QQ!&bO'#HVOOQq'#L]'#L]OOQq'#L^'#L^OOQq'#L_'#L_OOQq'#L`'#L`OOQq'#La'#LaOOQq'#Lb'#LbO!=XQ!LsO'#HXO!@mQ#${O'#H`OOQ'x'#Ld'#LdOOQ'x'#Le'#LeOOQ'x'#Lf'#LfOOQ'x'#Lg'#LgOOQ'x'#Lh'#LhOOQ'x'#Lc'#LcO!CeQ!&bO'#HaO!MzQ!&bO'#HaO#%_Q!&bO'#HhO!CeQ!&bO'#HgOOQq'#Hi'#HiOOQp'#Li'#LiO#%fQNYO'#HkOOQ'y'#Ll'#LlOOQ'y'#Lm'#LmOOQ'y'#Ln'#LnO#.^Q#${O'#HmOOQ'y'#Lt'#LtOOQ'y'#Lu'#LuO#.tQ#${O'#HtOOQp'#Lw'#LwO#/RQNYO'#HzO#/ZQNYO'#HzO!<qQNYO'#H}O!=QQ!&bO'#IPO#/`OMxO'#IQOOQ'y'#IS'#ISO#6rQ#${O'#IROOQ'y'#Ly'#LyO#>vQ#${O'#ITOOQ'x'#Lz'#LzO#E]Q!&bO'#IVOOQp'#L|'#L|OOQp'#L}'#L}OOQp'#MO'#MOOOQp'#L{'#L{O#EdQNYO'#IZOOQq'#MR'#MROOQq'#MS'#MSOOQq'#MQ'#MQO#EoQ!LsO'#I_OOQp'#MV'#MVOOQp'#MW'#MWOOQp'#MX'#MXOOQp'#MU'#MUO#IZQNYO'#IbOOQq'#Jd'#JdO#IlQNYO'#DbOOQ3O'#I{'#I{Q`Q!1hOOO#IwO$fO'#CtO#JPO! pO'#CuPOOO)CD})CD}O#JWQ!&bO,5:hO$ xQN^O,5>cO$']Q!&bO,5:iOOOO'#Ii'#IiO$'dOMhO'#J`O$'lO#tO,59qO$'tO#tO,59qO$'yO!$fO'#J[O$)aO!bO'#CyOOQ'y,59s,59sO$)fO! pO,59sO$)mO!$fO'#JZOOO%|'#JZ'#JZOOO%|'#Ig'#IgO$*}O!$fO,59tO$+UO#tO,59tO$ dQN^O,5>cO$+ZQN[O'#IlO$+cQNYO,5:PO$+kQN[O,5:OOOQ'y,5:T,5:TO!4]QNYO,5>hO!=QQ!&bO,5:[O$+sQN[O'#IrO$+{Q!&cO,5;eOOQp,5<d,5<dO$1eQ!1hO,5?cO$1lQ#${O'#EfO$2PQ!LrO,5APOCRQ!&bO'#DrO$4oQNYO,5:^O$4tQ!&bO'#DzO!+SQN^O'#EgO$5OQNYO'#ElO$5ZO#tO'#DvOOQq,5:`,5:`O$5cO#tO,5:`OOQq,5:c,5:cO#JWQ!&bO,5:cO$5hQ!LrO'#JlO$5rQNYO,5:eO$5wQ!LsO'#JlO$6OQNYO,5:fO$6TQNZO'#KzOOQq'#K{'#K{OOQq'#K|'#K|OOQq'#K}'#K}O$6_QNZO'#G`OOQ3O'#Kz'#KzOOQ3O'#Iq'#IqO$6lQ!1hO,5;bOOQ3P,5;b,5;bO$4tQ!&bO,5:fO$8aQ!LsO,5=mO$:cQ!&bO'#KiO!,}QNZO,5<TO!=QQ!&bO,5=OOOQ'x'#LO'#LOO!=QQ!&bO,5=QO$?oQ!&bO,5=TOOQ'x'#LP'#LPOOQ'x'#LQ'#LQOOQ'x'#LR'#LROOQ'x'#LS'#LSO!=QQ!&bO'#IyO$BrQ!LsO,5=TOOQ'x'#LT'#LTOOQ'x'#LU'#LUO!=QQ!&bO'#IzO$C`Q!LsO,5=TOOQ'x'#LV'#LVOOQ'x'#LW'#LWOOQ'x'#Gy'#GyOOQ'x'#LX'#LXOOQ'x'#LY'#LYOOQ'x'#LZ'#LZO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TOOQq,5=q,5=qO$C|Q!&bO,5>sOOQq,5:j,5:jO$DTO! pO,5:jO$D[O!$fO,5:kO$DfO#tO,5:kO$DkO!$fO,5:mO$DuO#tO,5:mO$DzO! pO,5:oO$ERO!$fO,5:qO$E]O#tO,5:qO$EbO!$fO,5:sO$EoO#tO,5:sO$EtO#tO,5:uO$EyO#tO,5:uOOQq,5:x,5:xO#JWQ!&bO,5:xOOQq,5:z,5:zO#JWQ!&bO,5:zOOQq,5:|,5:|O#JWQ!&bO,5:|O$NOQ#${O,5>SO$FOQ#${O,5>SOOQq,5;O,5;OO#JWQ!&bO,5;OO% WQN^O,5;ROOQq,5;R,5;RO% _QNYO,5<QO% dQ$IuO'#EyO% uQ$IuO,5;cO%!TQ(JRO'#EyO%'fQ(JRO,5;iO%,|Q!&bO'#KWO%-TQNYO,5;nOOQp'#KY'#KYO%-]QNYO,5;pOOQp'#KZ'#KZO%-nQNYO,5;rOOQq'#K]'#K]O%-yQNZO,5;tO!,}QNZO,5;vOOQp'#K_'#K_O%.^QNYO,5;yOOQq'#K`'#K`OOQq'#Ka'#KaO%.kQ$IuO,5;{O%/OQNZO'#EyO!,}QNZO,5;wOOQ'y'#Jm'#JmO%/ZQ!&cO'#IuO%/}QNZO,5AOO%0]OqO'#E{OOQ3P'#KS'#KSOOQ3O,5<P,5<PO%0hQ0>YO'#EnOOQq'#Er'#ErO%0oQNYO'#EpOOQq'#Ip'#IpO%0wQNYO,5;WOOQq'#Fh'#FhO%1PQNZO,5<QO!<qQNYO,5<nO%1bQ!1hO'#EvOOQq,5;W,5;WO%1rQNYO,5;WO!<qQNYO,5;WO%1zQNYO,5;WO%4iQ!LsO'#KeO%5]QNZO'#KhOOQq,5<U,5<UOCRQ!&bO'#DrO!<qQNYO,5<]O!<qQNYO,5<bO!<qQNYO,5<cO!4]QNYO,5<cO!4]QNYO,5<gO%5}Q$ItO,5<iO%=mQ!1iO,5<kO!<qQNYO,5<gO%=tQ!&cO,5<hO!<qQNYO,5<iO!4]QNYO,5<iO%>OQNYO,5<iO%>TQNYO,5<iOOQp'#Kq'#KqO!<qQNYO'#FyOOQ3O,5<k,5<kO%6fQ!1iO,5<kO%>fQNYO'#IwOOQq-E<u-E<uOOQ3O,5<l,5<lOOQ3O,5<n,5<nO%>kO,UO,5<vOOQ3O,5<w,5<wO%>pQ!LsO,5=mO%@rQ!LsO,5=qO%DTQNYO,5=sOOQq,5=z,5=zO%DYQ!LsO'#KVOOQq'#FR'#FROOQq,5={,5={O!-}Q!&bO,5>iOOQq,5>R,5>RO%EYQNYO'#DzOOQq'#Lk'#LkOOQq'#Lj'#LjO%EpQNYO'#LjOOQq,5>V,5>VO!=QQ!&bO'#LkO%EwQ#${O'#J[O$1lQ#${O'#EfO%MpQ!&bO'#DrOOQ'y'#Lp'#LpOOQ'y'#Lq'#LqOOQ'y'#Lr'#LrOOQ'y'#Ls'#LsOOQq'#Lo'#LoOOQq,5>X,5>XO&%YQ#${O'#LoO&/tQ#${O'#J[O&0UQ!&bO'#DrOOQq'#Lv'#LvO&5eQ#${O'#LvOOQq,5>`,5>`O&5rQ!LsO'#EyO&9ZQ!LsO,5>fO&<oQNYO,5>fO&>tQ!LsO,5>kOOQq,5>l,5>lO&@ZO`O,5>lOOQq,5>m,5>mOOQq,5>o,5>oO&HPQ#${O,5>qO&JsQ!LsO,5>qO%-TQNYO'#MPO&LSQNYO'#MPOOQq,5>u,5>uOOQq'#MT'#MTO&L[QNYO'#MTOOQq,5>y,5>yOOQq'#MY'#MYO&LdQNYO'#MYOOQq,5>|,5>|OOQq,59|,59|O#JWQ!&bO,59|OOQ3O-E<y-E<yOOO%},59`,59`O&LrOpO,59`O&LwO! pO,59aOOO%},59a,59aO' eQ!LrO1G0SO#JWQ!&bO1G0SO' lQ!&bO1G0TOOQq'#Hy'#HyO' sQ!LsO1G3}O'%XQNYO1G3}O'%^Q#$zO1G0TO''lQ!LrO1G0TOOOO-E<g-E<gO''sO!!^O,5?zOOO#t'#Ik'#IkO'(OO#tO1G/]OOQ'y1G/]1G/]O'(OO#tO1G/]O'(WOMhO'#IhO'(]O!bO,59fO'(yOMhO,59mO')QOMhO,59mO')YOMhO,59mO')eOMhO,59kO'*SOMhO,59eOOQ'y1G/_1G/_OOO%|-E<e-E<eOOQ'y1G/`1G/`O'*XO!$fO1G/`O'*XO!$fO1G/`OOQp,5?W,5?WOOQp-E<j-E<jOOQq'#Df'#DfOOQq1G/j1G/jOOQq1G4S1G4SO'*`Q!LsO1G/vOOQ'y,5?^,5?^OOQ'y-E<p-E<pO$6TQNZO'#IxOOQ3O'#Ix'#IxO'+oQ!1hO1G4}OOQq1G4}1G4}O'+vQ!&cO'#ImO',dQNYO,5@WPOQq1G6k1G6kOOQq1G/x1G/xOOO#t'#In'#InO',uO#tO,5:bOOQq,5:b,5:bOOQq1G/z1G/zO',}Q!LrO1G/}OOQq1G0P1G0POOQq1G0Q1G0QOOQ3O,5Af,5AfOOQ3O,5<z,5<zO!,}QNZO,5<zO$6TQNZO,5<zOOQ3O-E<o-E<oOOQ3P1G0|1G0|O'-UQNYO1G0QOOQq,5AT,5ATOOQ3O1G1o1G1oO'-ZQ!LsO1G2jO'.jQ!LsO1G2lO'3XQ!LsO1G2oO!=QQ!&bO1G2lO'5iQ!LsO,5?eOOQq-E<w-E<wO'8{Q!LsO,5?fOOQq-E<x-E<xO':[Q!LsO1G2oO'=kQ!LsO1G2oO'=xQ!LsO1G2oO'AXQ!LsO1G2oO'AlQ!LsO1G2oO'E_Q!LsO1G2oO'EfQ!LsO1G2oO'H{Q!LsO1G2oO'ISQ!LsO1G2oO'L`Q!LsO1G2oO'LpQ!LsO1G2oO'MQQ!LsO1G2oO'NaQ!LrO1G4_O!=QQ!&bO1G4_OOQq1G0U1G0UO'NhO#tO1G0VOOQq1G0V1G0VO'NmO!$fO1G0VO'NtO!$fO1G0VO( OO#tO1G0XO( TO&jO1G0XO( ]O!$fO1G0XO( dO!$fO1G0XO( nO&jO1G0ZO( vO! pO1G0ZO( }O#tO1G0]O(!SO&jO1G0]O(![O!$fO1G0]O(!cO!$fO1G0]OOO%|'#Jt'#JtO(!mO!!^O'#JtO(!uO#tO1G0_O(!}O!$fO1G0_O(#XO!$fO1G0_O(#cO!$fO1G0_O(!uO#tO1G0aO(#pO#tO1G0aO(#uQ!LrO1G0dO(#|Q!LrO1G0fO($TQ!LrO1G0hO($[Q#${O,5;eO(&yQ!LrO1G0jO0]QNYO'#DeOOQp'#J}'#J}O('QQN^O'#J}O('cQNYO'#J|O('nQNYO1G0mO%1PQNZO1G1lO('sQ$IuO,5;eOOQ3O1G0}1G0}O((UQNZO1G0}O((aQ(JRO,5;eOOQ3O1G1T1G1TO!,}QNZO1G1TO%'iQ!&cO1G1TO(-rQ!LrO,5@rOOQp,5@r,5@rO(-|QNYO1G1YO!,}QNZO1G1[OOQq'#K['#K[O!,}QNZO1G1^OOQ3O1G1`1G1`O!,}QNZO1G1`OOQ3O1G1b1G1bOOQp'#Ef'#EfO%-TQNYO1G1eO!,}QNZO1G1eOOQq'#Kc'#KcO%-]QNYO'#KcO(.WQNZO'#KbO!,}QNZO1G1gO(.fQNYO1G1gOOQ3O1G1c1G1cOOQq,5?a,5?aOOQq-E<s-E<sOOOq'#Is'#IsO(.kOqO,5;gOOQ3P,5;g,5;gOOQq,5;Y,5;YO(.vQNYO,5;YO(.{QNYO,5:^O(/QQNZO,5;[OOQp'#KP'#KPO(/cQNYO,5;`OOQq-E<n-E<nO!<qQNYO1G0rO%1zQNYO1G0rO%0wQNYO1G1lOOQ3O1G1l1G1lO(/hQNZO1G1lO((UQNZO1G1lO%1zQNYO1G1lOOQ3O1G2Y1G2YO(/vQNYO'#EpO%1rQNYO1G0rOOQq1G0r1G0rO%1zQNYO1G0rO(/{QNZO,5ASO(0mQ!1hO1G1wO(7tQ!1hO1G1|O(>{Q!1hO1G1}O!<qQNYO1G1}O!<qQNYO1G2RO%=tQ!&cO1G2SO!<qQNYO1G2TO!4]QNYO1G2TO(FPQNYO1G2TO(FUQNYO1G2TOOQ3O1G2V1G2VO(FgQ!1iO1G2VO(MnQ!1hO1G2RO)&rQ!LsO1G2SO!,}QNZO1G2SO)&|Q!1hO1G2TO).QQNYO1G2TOOQ3P,5<e,5<eOOQ3O1G2b1G2bOOQq1G3_1G3_O).VQ#${O'#ImO)1cQ!LsO,5@qO)4gQ!LsO'#KdOOQq1G4T1G4TO$4tQ!&bO,5:fP!=QQ!&bO,5BUO)7xQNYO,5BUO)8lQ!LsO,5BVO);jQ!LsO,5@WO)>nQNYO,5:^OCRQ!&bO,5BZOOQq,5BZ,5BZOHuQ!&bO,5:hO)>sQ!&bO,5:iOOQq,5Bb,5BbO)DjQ#$zO,5BbO)FcQNYO,5:^OCRQ!&bO,5BbOOQq1G4Q1G4QOOQp'#H{'#H{O)FhQNYO1G4QOOQq1G4W1G4WO!CeQ!&bO,5BkO%-TQNYO,5BkO)FpQNYO,5BoO)FuQNYO,5BtO)FzQ!LrO1G/hOOO%}1G.z1G.zOOO%}1G.{1G.{OOQq7+%n7+%nO)GRQ!LsO'#LjO)JQQ!LrO7+%nO)JXQ#$zO7+%oO)LgQ!LrO7+%oOOQq7+)i7+)iO)LnQNYO7+)iOOQq7+%o7+%oO)LsOMhO'#IjOOO#t'#Ij'#IjO)L{O!!^O1G5fOOO#t-E<i-E<iOOQ'y7+$w7+$wO)MWO#tO7+$wO)M`OMjO,5?SOOO!b-E<f-E<fOOOO'#J]'#J]O)MhQNYO'#J]O)MyOMhO1G/XO)NOOMhO1G/XO')eOMhO1G/VO)NVOMhO1G/XOOOO'#Jc'#JcO)N_QNYO'#JcO)NdQNYO'#JcO* OOMhO1G/VO* TOMjO1G/POOQ'y7+$z7+$zO* ]O!$fO7+$zOOQ3O,5?d,5?dOOQ3O-E<v-E<vOOQq7+*i7+*iO* dQ!LsO,5?XOOQq-E<k-E<kOOO#t-E<l-E<lOOQq1G/|1G/|OOQq7+%i7+%iOOQ3O1G2f1G2fO!,}QNZO1G2fO*!dQ!LsO7+%lO)1QQNZO,5@qO*)UQ!LsO7+(WO!=QQ!&bO7+)yO**eQ!LsO7+)yOOQq7+%q7+%qO*+tO#tO7+%qO*+yO!$fO7+%qO*,QO&jO7+%sOOQq7+%s7+%sO*,TO&jO7+%sO*,YO#tO7+%sO*,_O!$fO7+%sOOQq7+%u7+%uO*,fO&jO7+%uO*,kO&jO7+%uO*,sO&jO7+%wOOQq7+%w7+%wO*,vO&jO7+%wO*,{O#tO7+%wO*-QO!$fO7+%wOOO%|,5@`,5@`O*-XO#tO,5@`O*-^O!$fO7+%yO*-hO#tO7+%yO*-mO&jO7+%yO*-uO!$fO7+%yO(!uO#tO7+%yO(#XO!$fO7+%yO*-|O#tO7+%{O(!uO#tO7+%{OOQq7+&O7+&OOOQq7+&Q7+&QOOQq7+&S7+&SOOQq7+&U7+&UO*.RQNYO,5@iO*.WQN^O'#IoO*.eQNYO,5@hOOQq7+&X7+&XO%0wQNYO7+'WOOQ3O7+'W7+'WO(/hQNZO7+'WO((UQNZO7+'WO%1zQNYO7+'WOOQ3O7+&i7+&iOOQ3O7+&o7+&oO!,}QNZO7+&oO*.pQ(JRO7+&tOOQ3O7+&v7+&vOOQ3O7+&x7+&xOOQ3O7+&z7+&zO#JWQ!&bO7+'POOQ3O7+'P7+'PO*/TQNYO,5@}O*/YQNZO'#ItO*/mQNZO,5@|OOQ3O7+'R7+'RO*/{QNZO7+'ROOOq-E<q-E<qOOQ3P1G1R1G1ROOQq1G0t1G0tOOQq1G0y1G0yOOQq1G0v1G0vO*0]Q08QO'#EnOOQp1G0z1G0zOOQq7+&^7+&^O%1zQNYO7+&^O!<qQNYO7+&^O(/hQNZO7+'WO%1zQNYO7+'WOOQp'#Ko'#KoO!4]QNYO'#FrOOQ3O'#Iv'#IvO*0eQ!1hO7+'cOOQp'#Kp'#KpO!<qQNYO'#FtOOQ3O7+'c7+'cO*7lQ!1hO7+'hOOQ3O7+'h7+'hOOQ3O7+'i7+'iO*>sQ!1hO7+'iO*EwQ!1hO7+'mO)&rQ!LsO7+'nO!,}QNZO7+'nO*L{Q!1hO7+'oO!<qQNYO7+'oO!4]QNYO7+'oO+&PQNYO7+'oOOQ3O7+'q7+'qOOQ3O7+'m7+'mO#JWQ!&bO7+'nO+&UQNYO7+'nOOQ3O7+'o7+'oO+&ZQ#${O'#IuO+)RQ!LsO,5AOO+,dQNYO1G0QO+,iQ!LsO1G7pOOQq1G7p1G7pO#JWQ!&bO1G7pOOQq1G7u1G7uO+/zQNYO1G7uO+0PQ!LrO1G0SO+0^Q!LrO1G0TO+0kQNYO1G7|OOQq1G7|1G7|O+0pQ!LsO7+)lOOQq1G8V1G8VO$:cQ!&bO1G8VOOQq1G8Z1G8ZOOQq1G8`1G8`OOQq7+%S7+%SOOQq<<IY<<IYOOQq<<IZ<<IZO+4UQ!LsO<<MTOOO#t,5?U,5?UOOO#t-E<h-E<hOOQ'y<<Hc<<HcOOO!b1G4n1G4nO+7jQNYO,5?wOOO%|7+$s7+$sO+7oOMhO7+$sO+7tOMhO7+$qO+7yOMhO7+$sO')eOMhO7+$qOOOO,5?},5?}O+8QQNYO,5?}O+8VQNYO,5?}OOO%|7+$q7+$qOOO%|'#C}'#C}OOO%|7+$k7+$kOOQ'y<<Hf<<HfOOQ3O7+(Q7+(QO+:qQ!LsO1G/xO+;UQ!LsO<<MeOOQq<<I]<<I]OOQq<<I_<<I_O+<eO&jO<<I_O+<jO&jO<<I_OOQq<<Ia<<IaO+<rO&jO<<IaOOQq<<Ic<<IcO+<wO&jO<<IcO+<|O&jO<<IcOOO%|1G5z1G5zO+=UO#tO<<IeO+=ZO&jO<<IeO+=cO!$fO<<IeOOQq<<Ie<<IeO+=^O&jO<<IeO+=jO!$fO<<IeO+=tO#tO<<IgO+=yO#tO<<IgOOQp1G6T1G6TOOQp,5?Z,5?ZOOQp-E<m-E<mO((UQNZO<<JrO%1zQNYO<<JrO(/hQNZO<<JrOOQ3O<<Jr<<JrO%1zQNYO<<JrOOQ3O<<JZ<<JZOOQ3O<<J`<<J`O!,}QNZO<<J`O%'iQ!&cO<<J`O+>OQ!&cO<<J`O+>`Q!LsO<<JkOOQq1G6i1G6iOOQq,5?`,5?`OOQq-E<r-E<rO!,}QNZO<<JmO!<qQNYO<<IxOOQq<<Ix<<IxO!<qQNYO,5<^OOQ3O-E<t-E<tOOQ3O<<J}<<J}OOQ3O,5<`,5<`OOQ3O<<KS<<KSOOQ3O<<KT<<KTOOQ3O<<KX<<KXO#JWQ!&bO<<KYO+>jQNYO<<KYOOQ3O<<KZ<<KZO+>oQ!1hO<<KZO!<qQNYO<<KZO!4]QNYO<<KZO+>`Q!LsO<<KYO!<qQNYO<<KYOOQq7+%l7+%lO+EsQ!LrO7+-[OOQq7+-a7+-aOOQq7+-h7+-hOOQq<<MW<<MWO+EzQNYO7+-qO+FPQ!LsO1G/xO+IOQ!LsO1G/xOOQqANBoANBoOOOO1G5c1G5cOOO%|<<H_<<H_OOO%|<<H]<<H]O+K}OMhO<<H_O+LSOMhO<<H]OOOO1G5i1G5iO+LXQNYO1G5iOOQqAN>yAN>yO+L^O&jOAN>yOOQqAN>{AN>{OOQqAN>}AN>}O+LcO&jOAN>}O+LhO&jOAN?POOQqAN?PAN?PO+LkO&jOAN?PO+LpO#tOAN?PO+LuO!$fOAN?PO+L|O&jOAN?RO+MUO#tOAN?ROOQ3OAN@^AN@^O%1zQNYOAN@^O((UQNZOAN@^OOQ3OAN?zAN?zO!,}QNZOAN?zO%'iQ!&cOAN?zOOQ3OAN@VAN@VOOQ3OAN@XAN@XOOQqAN?dAN?dOOQ3O1G1x1G1xO+>`Q!LsOAN@tO!<qQNYOAN@tOOQ3OAN@uAN@uO+MZQ!1hOAN@uO!<qQNYOAN@uO#JWQ!&bOAN@tOOQ3OAN@tAN@tOOQq<=!v<=!vOOQq<=#]<=#]OOO%|AN=yAN=yOOO%|AN=wAN=wOOOO7++T7++TOOQqG24eG24eOOQqG24iG24iOOQqG24kG24kO,&_O&jOG24kO,&dO&jOG24kOOQqG24mG24mO,&lO&jOG24mO,&qO&jOG24mO((UQNZOG25xOOQ3OG25xG25xOOQ3OG25fG25fO!,}QNZOG25fO#JWQ!&bOG26`OOQ3OG26`G26`OOQ3OG26aG26aO,&yQ!1hOG26aO,-}Q!LrOG26`OOQqLD*VLD*VO,.UO&jOLD*VOOQqLD*XLD*XO,.ZO&jOLD*XOOQ3OLD+dLD+dOOQ3OLD+QLD+QO,.`Q!LrOLD+zOOQ3OLD+{LD+{O!<qQNYOLD+zOOQq!$'Mq!$'MqOOQq!$'Ms!$'MsO!<qQNYO!$( fOOQ3O!$( f!$( fOOQ3O!)9EQ!)9EQO,.gQNYO'#E^O#%fQNYO'#HkO#JWQ!&bO'#IPO,.rQ#${O'#IRO,/fQ#${O'#ITO,0YQ!&bO'#IVO,0aQNYO'#DbO#JWQ!&bO'#HRO#JWQ!&bO,5:[O,0lQ#${O'#EfO,3ZQ!LsO'#JlO#JWQ!&bO,5=OO#JWQ!&bO,5=QO,4QQ!&bO,5=TO#JWQ!&bO'#IyO,6hQ!LsO,5=TO#JWQ!&bO'#IzO,7UQ!LsO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO,7rQ!LsO'#KeO,=aQ!LsO,5=mO,>QQ!LsO'#KVO,>eQ#$zO'#J[O,F_Q#${O'#J[O,HvQ#${O'#J[O,KOQ!LsO,5>kO,K{Q#${O,5>qO,NYQ!LsO,5>qO- PQ#$zO1G0TO-#bQ!LsO1G/vO-$RQ!LsO1G2jO-$rQ!LsO1G2lO-(XQ!LsO1G2oO#JWQ!&bO1G2lO-(`Q!LsO,5?eO-)SQ!LsO,5?fO-)yQ!LsO1G2oO-,pQ!LsO1G2oO-,}Q!LsO1G2oO-/tQ!LsO1G2oO-0XQ!LsO1G2oO-3bQ!LsO1G2oO-3iQ!LsO1G2oO-6fQ!LsO1G2oO-6mQ!LsO1G2oO-9aQ!LsO1G2oO-9qQ!LsO1G2oO-:RQ!LsO1G2oO#JWQ!&bO1G4_O-:rQNYO,5:^O#JWQ!&bO,5BUO-:wQ!LrO,5BVO-;UQNYO,5:^O-;ZQNYO,5:^O-;`Q!LsO7+(WO#JWQ!&bO7+)yO-<PQ!LsO7+)yO-<vQ!LrO1G/xO-=QQ!LsO1G/xO-@PQ!LsO<<MeO-@vQ!LsO'#JdO-FWQ!&bO'#HRO#JWQ!&bO'#HRO#JWQ!&bO'#HVO-KhQ#${O'#H`O.'pQ#${O'#HmO.(WQ#${O'#HtO.(eQ!&bO,5>sOCRQ!&bO'#DrO!=QQ!&bO'#LkO%MpQ!&bO'#DrO&0UQ!&bO'#DrO.(lQ!LrO1G4_O.(sQ!&bO,5BkO.(zQNYO,5:^O.)PQNYO,5:^O.(sQ!&bO'#HaO.._Q!&bO'#HaO.(sQ!&bO'#HgO%-TQNYO'#MPOCRQ!&bO'#DrOCRQ!&bO'#DrO..fQNYO'#IZ",
  stateData: "./a~OgOS'|OS'sPQ'tPQ~OQ]OR#dOS#kOT#}OU$OOd#SOjQOkROlROpfOwnOxXOzSO}VO!OhO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO#l!ZO#p#RO#r!]O#s!^O#w!aO$Q!bO$Z!fO$_!iO$`!kO$a!lO$b!mO$c!nO$d!oO$w!zO$x!{O$y!|O$z!}O${#OO%Q#TO%R#UO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO)k#QO*l$PO~O's$iO't$jO~Ov$mOw$nO!Q$lOo(OX!R(OX!^(OX!e(OX!g(OX!o(OX!x(OX#T(OX#V(OX#X(OX#p(OX#w(OX$`(OX$a(OX$b(OX$c(OX$d(OX%X(OX%Z(OX%[(OX%^(OX%_(OX%`(OX%a(OX%b(OX%c(OX%d(OX%e(OX%f(OX%g(OX%h(OX%i(OX%j(OX%k(OX%l(OX%n(OX%o(OX%p(OX%q(OX%r(OX%s(OX%t(OX%z(OX&|(OX'q(OX!P(OXr(OXt(OX#e(OX~O^$qO'|$oO~OQ$xO[$xO]$xOj$sOkROlRO!V5ZO#R5TO's$iO't$jO~O(T$uO~P+vO^$zO'|$oO~Ov$|Ov(QXw(QX!Q(QX!R(QX!^(QX!e(QX!g(QX!o(QX!x(QX#T(QX#V(QX#X(QX#p(QX#w(QX$`(QX$a(QX$b(QX$c(QX$d(QX%X(QX%Z(QX%[(QX%^(QX%_(QX%`(QX%a(QX%b(QX%c(QX%d(QX%e(QX%f(QX%g(QX%h(QX%i(QX%j(QX%k(QX%l(QX%n(QX%o(QX%p(QX%q(QX%r(QX%s(QX%t(QX%z(QX&|(QX'q(QX!P(QXr(QXt(QX#e(QX~Oo$}Oo!XX!e(XX!g(XX!P(XX~Ov(XXw(XX!Q(XX!R(XX!^(XX!o(XX!x(XX#T(XX#V(XX#X(XX#p(XX#w(XX$`(XX$a(XX$b(XX$c(XX$d(XX%X(XX%Z(XX%[(XX%^(XX%_(XX%`(XX%a(XX%b(XX%c(XX%d(XX%e(XX%f(XX%g(XX%h(XX%i(XX%j(XX%k(XX%l(XX%n(XX%o(XX%p(XX%q(XX%r(XX%s(XX%t(XX%z(XX&|(XX'q(XXr(XXt(XX#e(XX~P0]Oo%PO~OY%QO~Ov%ROw!_X!Q!_X!R!_X!^!_X!e!_X!g!_X!o!_X!x!_X#T!_X#V!_X#X!_X#p!_X#w!_X$`!_X$a!_X$b!_X$c!_X$d!_X%X!_X%Z!_X%[!_X%^!_X%_!_X%`!_X%a!_X%b!_X%c!_X%d!_X%e!_X%f!_X%g!_X%h!_X%i!_X%j!_X%k!_X%l!_X%n!_X%o!_X%p!_X%q!_X%r!_X%s!_X%t!_X%z!_X&|!_X'q!_X!P!_Xr!_Xt!_X#e!_X~Oo%TO!e%SOQ&[XR&[XS&[XT&[XU&[Xj&[Xj&oXk&[Xl&[Xp&[Xp&oXv#mXx&[Xz&[X}&[X!O&[X!Q&[X!R&[X!S&[X!T&[X!V&[X!Z&[X![&[X!^&[X!`&[X!a&[X!b&[X!c&[X!g#YX!i&[X!l&[X!o&[X!t&[X!v&[X!x#YX!z&[X!|&[X#O&[X#P&[X#R&[X#T&[X#V&[X#X&[X#[&[X#]&[X#^&[X#_&[X#a&[X#p#YX#w#YX$`#YX$a#YX$b#YX$c#YX$d#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX%v&[X%w&[X%x&[X%z&[X%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X&|#YX'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'q#YX'x&[X(T&[X(c&[X*l&[Xt#YX~Ow%WO#e%VO~P7eOv(WXw(WX!Q(WX!R(WX!^(WX!o(WX!x(WX#T(WX#V(WX#X(WX#p(WX%X(WX%Z(WX%[(WX%^(WX%_(WX%`(WX%a(WX%b(WX%c(WX%d(WX%e(WX%f(WX%g(WX%h(WX%i(WX%j(WX%k(WX%l(WX%n(WX%o(WX%p(WX%q(WX%r(WX%s(WX%t(WX%z(WX&|(WX'q(WX!P(WXr(WXt(WX#e(WX~O!e%SO!g(WX#w(WX$`(WX$a(WX$b(WX$c(WX$d(WX~P?lOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!O%ZO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO!P(`P~O^%`O'|$oO~Oj%cOp%cOw%dO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!O%ZO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$POr(`P~O%T%jO%U%kO%V%lOt(`P~P`OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!O%ZO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~Ow%rO~PNfOv$mOw$nO!Q$lO!R&^O!^&_O!o&^O!x&]O#T&]O#V&WO#X&]O#w!aO$`!kO$a!lO$b!mO$c!nO$d!oO%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO!e)XX!g)XX#p)XX'q)XX~O(c&kO~P+vO^&mO'|$oO~O^&oO'|$oO~O!x&qO~O^&rO'|$oO~O^&tO'|$oO~O^&vO'|$oO~Oj&xOw&yO!V$fO~Oj&zOw&{O!V$fO~Oj&|Op'OOw&}O!V$fO~Oj'QOw'RO!V$fO~OQ]OjROkROlRO!O'SO!Z'TO~O#a!YO~P!+SOp'VO~Op'XO#n'cO#t'YO#w!aO#{'_O#}'aO~O#y']O$S'dO$U'fO$V'gO~P!+tOp'iO~O!e'kO!g'kO#p)WX'q)WX~O#p'nO'q'oO~O$w!zO$x!{O$y!|O$z!}O${#OO~Op'vOw'yO!O'qO#e'sO~P!-VO#a!YO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OhO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~O#w)[P$`)[P$a)[P$b)[P$c)[P$d)[P#p)[P'q)[P~P!-}O#w!aO$`!kO$a!lO$b!mO$c!nO$d!oO~O!O(RO~Ow'yO$a!lO$b!mO$c!nO$d!oO~Oj(^O!O([O#[!SO#]!TO#^!UO#_!VO$r(`O~O#p'nO$n(aO'q'oOQ$sXR$sXS$sXT$sXU$sXd$sXj$sXk$sXl$sXp$sXw$sXx$sXz$sX}$sX!O$sX!Q$sX!R$sX!S$sX!T$sX!V$sX!Z$sX![$sX!^$sX!`$sX!a$sX!b$sX!c$sX!i$sX!l$sX!o$sX!t$sX!v$sX!z$sX!|$sX#O$sX#P$sX#R$sX#T$sX#V$sX#X$sX#[$sX#]$sX#^$sX#_$sX#a$sX#l$sX#p$sX#r$sX#s$sX#w$sX$Q$sX$Z$sX$_$sX$`$sX$a$sX$b$sX$c$sX$d$sX$w$sX$x$sX$y$sX$z$sX${$sX%Q$sX%R$sX%v$sX%w$sX%x$sX%z$sX%|$sX%}$sX&O$sX&P$sX&Q$sX&R$sX&U$sX&V$sX&W$sX&X$sX&Y$sX&`$sX&b$sX&c$sX&d$sX&i$sX&j$sX&l$sX&x$sX&z$sX'O$sX'P$sX'Q$sX'S$sX'T$sX'V$sX'W$sX'X$sX'p$sX'x$sX(T$sX(c$sX)k$sX*l$sXt$sX%T$sX%U$sX%V$sX~Op(eO#p$uX'q$uX~Ow'yO~Oe(iO~O'z(jO~Ow%]O~PNfO!O(mOv%{Xw%{X!Q%{X!R%{X!^%{X!e%{X!g%{X!o%{X!x%{X#T%{X#V%{X#X%{X#p%{X#w%{X$`%{X$a%{X$b%{X$c%{X$d%{X%X%{X%Z%{X%[%{X%^%{X%_%{X%`%{X%a%{X%b%{X%c%{X%d%{X%e%{X%f%{X%g%{X%h%{X%i%{X%j%{X%k%{X%l%{X%n%{X%o%{X%p%{X%q%{X%r%{X%s%{X%t%{X%z%{X&|%{X'q%{X!P%{Xr%{Xt%{X#e%{X~Ov&SX!e&SX!g&SX!x&SX#p&SX#w&SX$`&SX$a&SX$b&SX$c&SX$d&SX%X&SX%Z&SX%[&SX%^&SX%_&SX%`&SX%a&SX%b&SX%c&SX%d&SX%e&SX%f&SX%g&SX%h&SX%i&SX%j&SX%k&SX%l&SX%n&SX%o&SX%p&SX%q&SX%r&SX%s&SX%t&SX&|&SX'q&SX!P&SXr&SXt&SX#e&SX~P!-}OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!O(RO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!O(RO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~OwnO~P!HqOQ&[XR&[XS&[XT&[XU&[Xj&[Xk&[Xl&[Xp&[Xw&[Xx&[Xz&[X}&[X!O&[X!Q&[X!R&[X!S&[X!T&[X!V&[X!Z&[X![&[X!^&[X!`&[X!a&[X!b&[X!c&[X!i&[X!l&[X!o&[X!t&[X!v&[X!z&[X!|&[X#O&[X#P&[X#R&[X#T&[X#V&[X#X&[X#[&[X#]&[X#^&[X#_&[X#a&[X%v&[X%w&[X%x&[X%z&[X%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'x&[X(T&[X(c&[X*l&[X~Ov$|O~P!NROj(uOw%]O!O(wO!QmO!o(tO#a!YO%w(yO~OQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$POv(`Pw(`P!Q(`P!R(`P!e(`P!g(`P!o(`P!x(`P#T(`P#V(`P#X(`P#p(`P#w(`P$`(`P$a(`P$b(`P$c(`P$d(`P%X(`P%Z(`P%[(`P%^(`P%_(`P%`(`P%a(`P%b(`P%c(`P%d(`P%e(`P%f(`P%g(`P%h(`P%i(`P%j(`P%k(`P%l(`P%n(`P%o(`P%p(`P%q(`P%r(`P%s(`P%t(`P%z(`P&|(`P'q(`P!P(`Pr(`Pt(`P#e(`P~Oj(zOp({O!O(|O&e(}O&f)OO&g)PO~P#%}Oj)UOp%XO!O)VO~P#%}Oj)[Op)ZO~Oo)]O~OV)`OW)`OX)_Oj)`Op)`O&e(}O&f)OO&g)PO~OQ]OU$OOjQOkROlROwnOxXOzSO}VO!OhO!QmO!S$eO!T$eO!V$fO!Z$eO!^^O!``O!aaO!bbO!ccO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%x#XO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$POv&uX!x&uX#p&uX%X&uX%Z&uX%[&uX%^&uX%_&uX%`&uX%a&uX%b&uX%c&uX%d&uX%e&uX%f&uX%g&uX%h&uX%i&uX%j&uX%k&uX%l&uX%n&uX%o&uX%p&uX%q&uX%r&uX%s&uX%t&uX&|&uX'q&uX!P&uXr&uXt&uX#e&uX~OR#dOS#kOT#}Op%XO!R#YO![gO!ooO%v#YO%w#YO%z#[O!e&uX!g&uX#w&uX$`&uX$a&uX$b&uX$c&uX$d&uX~P#/zOQ]OU$OOjQOkROlROwnOxXOzSO}VO!OhO!QmO!S$eO!T$eO!V$fO!Z$eO!^^O!``O!aaO!bbO!ccO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%x#XO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$POv&wX!x&wX#p&wX%X&wX%Z&wX%[&wX%^&wX%_&wX%`&wX%a&wX%b&wX%c&wX%d&wX%e&wX%f&wX%g&wX%h&wX%i&wX%j&wX%k&wX%l&wX%n&wX%o&wX%p&wX%q&wX%r&wX%s&wX%t&wX&|&wX'q&wX!P&wXr&wXt&wX#e&wX~OR#dOS#kOT#}Op%XO!R#YO![gO!ooO%v#YO%w#YO%z#[O!e&wX!g&wX#w&wX$`&wX$a&wX$b&wX$c&wX$d&wX~P#8OOQ]OR#dOS#kOT#}OU$OOjQOkROlROw%]OxXOzSO}VO!O%ZO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~Op)cO~P#@SOk)eO!O)fO#R!OO~Ok)hO!O)iO#R!OOv'RXw'RX!Q'RX!R'RX!^'RX!e'RX!g'RX!o'RX!x'RX#T'RX#V'RX#X'RX#p'RX#w'RX$`'RX$a'RX$b'RX$c'RX$d'RX%X'RX%Z'RX%['RX%^'RX%_'RX%`'RX%a'RX%b'RX%c'RX%d'RX%e'RX%f'RX%g'RX%h'RX%i'RX%j'RX%k'RX%l'RX%n'RX%o'RX%p'RX%q'RX%r'RX%s'RX%t'RX%z'RX&|'RX'q'RX!P'RXr'RXt'RX#e'RX~Ok)kOl)kO!O)lO#R!OO#T!PO~Oj)nOw)oO!V$fO~OZ)qOa)rO~OZ)tO~P+vOQ]OR6sOS7POT5VOU$OOjQOkROlROp5^Ow%]OxXOzSO}VO!O%ZO!QmO!R5[O!S$eO!T$eO!V$fO!Z$eO![6oO!^^O!``O!aaO!bbO!ccO!iiO!llO!o6pO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5[O%w5[O%x#XO%z6rO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~OQ)yOj)yOp)xO!O(RO!V$fO&l#yO~Ow)wO!Q)vO~P$ dOQ]OR6sOS7POT5VOU$OOjQOkROlROw%]OxXOzSO}VO!O%ZO!QmO!R5[O!S$eO!T$eO!V$fO!Z$eO![6oO!^^O!``O!aaO!bbO!ccO!iiO!llO!o6pO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5[O%w5[O%x#XO%z6rO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~Op){O~P$!SOg*OO'|$oO~O`*ROa*PO~O^*SO~Ov*WOw*VO!Q*YO'u*XO'v*TOQ(OX[(OX](OXj(OXk(OXl(OX!V(OX#R(OX's(OX't(OX'wnX(T(OX(c(OXZ(OX`(OX!x(OX_(OX~O'w*ZO~O(T*[O~P+vOv*WOw*VO!Q*YO'u*XOQ'}X['}X]'}Xj'}Xk'}Xl'}X!V'}X#R'}X's'}X't'}X(T'}X(c'}XZ'}X`'}X!x'}X_'}X~O`*^O~P+vO^*`O~OP*aOp*aO~Oo$}Oo!Xa~OP*cOp*cO~OP*gOp*gO~Oo%TOQ#maR#maS#maT#maU#maj#mak#mal#map#mav#maw#max#maz#ma}#ma!O#ma!Q#ma!R#ma!S#ma!T#ma!V#ma!Z#ma![#ma!^#ma!`#ma!a#ma!b#ma!c#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%v#ma%w#ma%x#ma%z#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&R#ma&U#ma&V#ma&W#ma&X#ma&Y#ma&`#ma&b#ma&c#ma&d#ma&i#ma&j#ma&l#ma&x#ma&z#ma'O#ma'P#ma'Q#ma'S#ma'T#ma'V#ma'W#ma'X#ma'x#ma(T#ma(c#ma*l#ma#p#ma'q#ma~Ot*lO~P`Ow&[Xw&rX!P#YXr#YX#e#YX~P7eOv$mOw$nO!Q$lO!R&^O!^&_O!e'kO!g'kO!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO!P(`X~O!P*pO~Ow%]Ot(`P~PNfOw'yO!O'qO#e'sO~O`*sOb*qO~O^%`O~Or(`Xt(`X~P$2POr*vO~Ot(`X~P!%vOt*wO~O#p'nO'q'oO~P!3wOp*{O#p'nO'q'oO~P!3wOt*}O%T%jO%U%kO%V%lO~P`Ov$mOw$nO!Q$lO%z&iO!e%ua!g%ua#p%ua#w%ua$`%ua$a%ua$b%ua$c%ua$d%ua%r%ua%s%ua%t%ua'q%ua!P%uar%uat%ua#e%ua~O!R%ua!^%ua!o%ua!x%ua#T%ua#V%ua#X%ua%X%ua%Z%ua%[%ua%^%ua%_%ua%`%ua%a%ua%b%ua%c%ua%d%ua%e%ua%f%ua%g%ua%h%ua%i%ua%j%ua%k%ua%l%ua%n%ua%o%ua%p%ua%q%ua&|%ua~P$6|OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!O6wO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~Ow%]O%X+UO~PNfOv%]aw%]a!Q%]a!R%]a!^%]a!e%]a!g%]a!o%]a!x%]a#T%]a#V%]a#X%]a#p%]a#w%]a$`%]a$a%]a$b%]a$c%]a$d%]a%X%]a%Z%]a%[%]a%^%]a%_%]a%`%]a%a%]a%j%]a%k%]a%l%]a%n%]a%o%]a%p%]a%q%]a%r%]a%s%]a%t%]a%z%]a&|%]a'q%]a!P%]ar%]at%]a#e%]a~O%b&OO%c%zO%d%{O%e%|O%f%}O%g%]a%h%]a%i%]a~P$?yO%g&SO%h&QO%i&RO%b%]a%c%]a%d%]a%e%]a%f%]a~P$?yO#e+hO~P#JWO(c+iO~P+vO`+kOa+jO~P+vO^+mO~O`+oOa+nO~P+vO^+qO~O!x+rO~P+vO`+uOa+tO~P+vO^+wO~O_+xO`+yOa+zO~P+vO^+}O~Oa,OO~O^,PO~OQ&[aR&[aS&[aT&[aU&[aj&[ak&[al&[ap&[av&^aw&[ax&[az&[a}&[a!O&[a!Q&[a!R&[a!S&[a!T&[a!V&[a!Z&[a![&[a!^&[a!`&[a!a&[a!b&[a!c&[a!e&^a!g&^a!i&[a!l&[a!o&[a!t&[a!v&[a!x&^a!z&[a!|&[a#O&[a#P&[a#R&[a#T&[a#V&[a#X&[a#[&[a#]&[a#^&[a#_&[a#a&[a#p&^a#w&^a$`&^a$a&^a$b&^a$c&^a$d&^a%X&^a%Z&^a%[&^a%^&^a%_&^a%`&^a%a&^a%b&^a%c&^a%d&^a%e&^a%f&^a%g&^a%h&^a%i&^a%j&^a%k&^a%l&^a%n&^a%o&^a%p&^a%q&^a%r&^a%s&^a%t&^a%v&[a%w&[a%x&[a%z&[a%|&[a%}&[a&O&[a&P&[a&Q&[a&R&[a&U&[a&V&[a&W&[a&X&[a&Y&[a&`&[a&b&[a&c&[a&d&[a&i&[a&j&[a&l&[a&x&[a&z&[a&|&^a'O&[a'P&[a'Q&[a'S&[a'T&[a'V&[a'W&[a'X&[a'q&^a'x&[a(T&[a(c&[a*l&[a!P&^ar&^at&^a#e&^a~Oo%TOw&^a!Q&^a!R&^a!^&^a!o&^a#T&^a#V&^a#X&^a%z&^a~P$FOOQ]OjROkROlRO!O,XO!Z,WO~O!P(pP~P$NrOp'vO~Oo%TOw#mX#n#mX#p#mX'q#mX~Ow'yO#n,_O#p'nO'q'oO~OQ#mXR#mXS#mXT#mXU#mXj#mXk#mXl#mXp#mXx#mXz#mX}#mX!O#mX!Q#mX!R#mX!S#mX!T#mX!V#mX!Z#mX![#mX!^#mX!`#mX!a#mX!b#mX!c#mX!i#mX!l#mX!o#mX!t#mX!v#mX!z#mX!|#mX#O#mX#P#mX#R#mX#T#mX#V#mX#X#mX#[#mX#]#mX#^#mX#_#mX#a#mX%v#mX%w#mX%x#mX%z#mX%|#mX%}#mX&O#mX&P#mX&Q#mX&R#mX&U#mX&V#mX&W#mX&X#mX&Y#mX&`#mX&b#mX&c#mX&d#mX&i#mX&j#mX&l#mX&x#mX&z#mX'O#mX'P#mX'Q#mX'S#mX'T#mX'V#mX'W#mX'X#mX'x#mX(T#mX(c#mX*l#mX!e#mX!g#mX~P% dO#n,cO#p'nO'q'oO~P$:cOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~O!O7UO~P%'sO!e'kO!g'kO~OxYOzSO}VO!^^O(TUO~Ok,hO!O%ZO!iiO~Ok,hO!O%ZO!iiO#p'nO'q'oO~P%-]Op,mOw%]O!o(tO~P%-]O!O,qO!iiO$W,tO#p)UP'q)UP~P%-]Oo%TO#p#mX'q#mX~O!e'iX!g'iX#p'iX'q'iX#w'iX$`'iX$a'iX$b'iX$c'iX$d'iX~P!-}O!e'kO!g'kO#p)Wa'q)Wa~O'r,zO's$iO't$jO~O#c,|O~PCROp-OO#i-PO~O!O(RO#e'sO~Ow'yO!O'qO#e'sO#p'nO'q'oO~Ot%qO%T%jO%U%kO%V%lO~P`Ow'yO#e-[O~O!O(RO#e-[O~Ov$mOw$nO!Q$lO!R&^O!^&_O!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO~O!e)XX!g)XX#w)XX$`)XX$a)XX$b)XX$c)XX$d)XX#p)XX'q)XX~P%2SO!e'kO!g'kO#w)[X$`)[X$a)[X$b)[X$c)[X$d)[X#p)[X'q)[X~Oj-hO!O-fO#[!SO#]!TO#^!UO#_!VO$r-jO~O#p'nO'q'oOQ$saR$saS$saT$saU$sad$saj$sak$sal$sap$saw$sax$saz$sa}$sa!O$sa!Q$sa!R$sa!S$sa!T$sa!V$sa!Z$sa![$sa!^$sa!`$sa!a$sa!b$sa!c$sa!i$sa!l$sa!o$sa!t$sa!v$sa!z$sa!|$sa#O$sa#P$sa#R$sa#T$sa#V$sa#X$sa#[$sa#]$sa#^$sa#_$sa#a$sa#l$sa#p$sa#r$sa#s$sa#w$sa$Q$sa$Z$sa$_$sa$`$sa$a$sa$b$sa$c$sa$d$sa$w$sa$x$sa$y$sa$z$sa${$sa%Q$sa%R$sa%v$sa%w$sa%x$sa%z$sa%|$sa%}$sa&O$sa&P$sa&Q$sa&R$sa&U$sa&V$sa&W$sa&X$sa&Y$sa&`$sa&b$sa&c$sa&d$sa&i$sa&j$sa&l$sa&x$sa&z$sa'O$sa'P$sa'Q$sa'S$sa'T$sa'V$sa'W$sa'X$sa'p$sa'x$sa(T$sa(c$sa)k$sa*l$sat$sa%T$sa%U$sa%V$sa~O$n(aO~P%6fO#p'nO'q'oO~PCROj-hO~Ol-hO#[!SO#]!TO#^!UO#_!VO~Ow%WO~Of-sO~O!R&^O!^&_O!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO&|&jO~P$6|Ov$mOw$nO!Q$lO!R%ya!^%ya!e%ya!g%ya!o%ya!x%ya#T%ya#V%ya#X%ya#p%ya#w%ya$`%ya$a%ya$b%ya$c%ya$d%ya%X%ya%Z%ya%[%ya%^%ya%_%ya%`%ya%a%ya%b%ya%c%ya%d%ya%e%ya%f%ya%g%ya%h%ya%i%ya%j%ya%k%ya%l%ya%n%ya%o%ya%p%ya%q%ya%r%ya%s%ya%t%ya%z%ya&|%ya'q%ya!P%yar%yat%ya#e%ya~O!P-tO~O!e'kO!g'kO#p(yX#w(yX$`(yX$a(yX$b(yX$c(yX$d(yX'q(yX!P(yXr(yXt(yX#e(yX~P%2SOw-yO~Oj(uOw%]O!QmO!o(tO#a!YO~O%w6xO~P%E_OQ*gXR*gXS*gXT*gXU*gXj*gXk*gXl*gXp*gXx*gXz*gX}*gX!O*gX!R*gX!S*gX!T*gX!V*gX!Z*gX![*gX!^*gX!`*gX!a*gX!b*gX!c*gX!e*gX!g*gX!i*gX!l*gX!o*gX!t*gX!v*gX!x*gX!z*gX!|*gX#O*gX#P*gX#R*gX#T*gX#V*gX#X*gX#[*gX#]*gX#^*gX#_*gX#a*gX#p*gX#w*gX$`*gX$a*gX$b*gX$c*gX$d*gX%X*gX%Z*gX%[*gX%^*gX%_*gX%`*gX%a*gX%b*gX%c*gX%d*gX%e*gX%f*gX%g*gX%h*gX%i*gX%j*gX%k*gX%l*gX%n*gX%o*gX%p*gX%q*gX%r*gX%s*gX%t*gX%v*gX%w*gX%x*gX%z*gX%|*gX%}*gX&O*gX&P*gX&Q*gX&R*gX&U*gX&V*gX&W*gX&X*gX&Y*gX&`*gX&b*gX&c*gX&d*gX&i*gX&j*gX&l*gX&x*gX&z*gX&|*gX'O*gX'P*gX'Q*gX'S*gX'T*gX'V*gX'W*gX'X*gX'q*gX'x*gX(T*gX(c*gX*l*gX!P*gXr*gXt*gX#e*gX~P(YOQ]OR#dOS#kOT#}OU$OOj5wOkROlROp({OwnOxXOzSO}VO!O%ZO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&e(}O&f)OO&g)PO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO!P(`P~Ov(`P!e(`P!g(`P!x(`P#p(`P#w(`P$`(`P$a(`P$b(`P$c(`P$d(`P%X(`P%Z(`P%[(`P%^(`P%_(`P%`(`P%a(`P%b(`P%c(`P%d(`P%e(`P%f(`P%g(`P%h(`P%i(`P%j(`P%k(`P%l(`P%n(`P%o(`P%p(`P%q(`P%r(`P%s(`P%t(`P&|(`P'q(`Pr(`Pt(`P#e(`P~PCROQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!O%ZO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO!e(`P!g(`P!x(`P#p(`P#w(`P$`(`P$a(`P$b(`P$c(`P$d(`P%X(`P%Z(`P%[(`P%^(`P%_(`P%`(`P%a(`P%b(`P%c(`P%d(`P%e(`P%f(`P%g(`P%h(`P%i(`P%j(`P%k(`P%l(`P%n(`P%o(`P%p(`P%q(`P%r(`P%s(`P%t(`P&|(`P'q(`P!P(`Pr(`Pt(`P#e(`P~Ov$mOw.SO!Q.ROo(OX~P&'}OQ]OR#dOS#kOT#}OU$OOj.UOkROlROp%XOwnOxXOzSO}VO!O%ZO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO!P(`P~Ow%]O!QmOv(`P~P&'}Oo%TOv#mXw#mX!O#mX!Q#mX!R#mX!^#mX!e#mX!g#mX!o#mX!x#mX#T#mX#V#mX#X#mX#p#mX#w#mX$`#mX$a#mX$b#mX$c#mX$d#mX%X#mX%Z#mX%[#mX%^#mX%_#mX%`#mX%a#mX%b#mX%c#mX%d#mX%e#mX%f#mX%g#mX%h#mX%i#mX%j#mX%k#mX%l#mX%n#mX%o#mX%p#mX%q#mX%r#mX%s#mX%t#mX%z#mX&|#mX'q#mX!P#mXr#mXt#mX#e#mX~O!O(ROv&naw&na!Q&na!R&na!^&na!e&na!g&na!o&na!x&na#T&na#V&na#X&na#p&na#w&na$`&na$a&na$b&na$c&na$d&na%X&na%Z&na%[&na%^&na%_&na%`&na%a&na%b&na%c&na%d&na%e&na%f&na%g&na%h&na%i&na%j&na%k&na%l&na%n&na%o&na%p&na%q&na%r&na%s&na%t&na%z&na&|&na'q&na!P&nar&nat&na#e&na~Op.YO~Ov$mOw$nO!Q$lO%[%wO%c%zO%d%{O%e%|O%f%}O%h&QO%i&RO%k&UO%z&iO#V&sa#p&sa%X&sa%Z&sa%l&sa%n&sa%o&sa%p&sa%q&sa%r&sa%s&sa%t&sa&|&sa'q&sa!P&sar&sat&sa#e&sa~O!R&^O!^&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O%b&OO%g&SO%j&`O!e&sa!g&sa#w&sa$`&sa$a&sa$b&sa$c&sa$d&sa~P&<tOX.[O~Oo%TOQ&[XR&[XS&[XT&[XU&[Xj&[Xj&oXk&[Xl&[Xp&[Xp&oXv&yaw&yax&[Xz&[X}&[X!O&[X!Q&ya!R&ya!S&[X!T&[X!V&[X!Z&[X![&[X!^&ya!`&[X!a&[X!b&[X!c&[X!i&[X!l&[X!o&ya!t&[X!v&[X!x&ya!z&[X!|&[X#O&[X#P&[X#R&[X#T&ya#V&ya#X&ya#[&[X#]&[X#^&[X#_&[X#a&[X#p&ya%X&ya%Z&ya%[&ya%^&ya%_&ya%`&ya%a&ya%b&ya%c&ya%d&ya%e&ya%f&ya%g&ya%h&ya%i&ya%j&ya%k&ya%l&ya%n&ya%o&ya%p&ya%q&ya%r&ya%s&ya%t&ya%v&[X%w&[X%x&[X%z&ya%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X&|&ya'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'q&ya'x&[X(T&[X(c&[X*l&[X!P&yar&yat&ya#e&ya~O!e&ya!g&ya#w&ya$`&ya$a&ya$b&ya$c&ya$d&ya~P&@`Ov$mOw$nO!Q$lO!R&^O!^&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%z&iO&|&jO~O!e&ya!g&ya#p&ya#w&ya$`&ya$a&ya$b&ya$c&ya$d&ya%X&ya%Z&ya%r&ya%s&ya%t&ya'q&ya!P&yar&yat&ya#e&ya~P&HmOk.^O#R!OO~Ok._O#R!OO~Ok.`Ol.`O#R!OO#T!PO~OZ.bO~OZ.cO~P+vOv$mOw$nO!Q$lO!R5iO!^5jO!o5iO!x5hO#T5hO#V&WO#X5hO%X5`O%Z5aO%[%wO%^5gO%_5gO%`5iO%a5jO%b5cO%c%zO%d%{O%e%|O%f%}O%g5eO%h&QO%i&RO%j5kO%k&UO%l&VO%n5nO%o5oO%p5pO%q5qO%r&XO%s&YO%t&ZO%z&iO&|6vO~Or.dO~P&MOOp.gO~P$!SO!O(ROv&kiw&ki!Q&ki!R&ki!^&ki!e&ki!g&ki!o&ki!x&ki#T&ki#V&ki#X&ki#p&ki#w&ki$`&ki$a&ki$b&ki$c&ki$d&ki%X&ki%Z&ki%[&ki%^&ki%_&ki%`&ki%a&ki%b&ki%c&ki%d&ki%e&ki%f&ki%g&ki%h&ki%i&ki%j&ki%k&ki%l&ki%n&ki%o&ki%p&ki%q&ki%r&ki%s&ki%t&ki%z&ki&|&ki'q&ki!P&kir&kit&ki#e&ki~Oo.jO~Oo%TOt.kO!e5]Oj&oXp&oXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROt.kO~P&MOOg.mO'|$oO^(Sa~O`.pOa*PO~Oo.rO~O'v*TO'wna~Oj.tOxYOzSO}VO!O.uO(TUO~Op.vO~P'(eOw.wO!Q.xO~Ov.yOw.wO!Q.xO~Oj.zOxYOzSO}VO!O.|O!R.{O!S.zO!T.zO(TUO~Oo/OO~O`/PO~P+vO%X%vO%Z%xO!e!di!g!di#p!di#w!di$`!di$a!di$b!di$c!di$d!di%r!di%s!di%t!di'q!di!P!dir!dit!di#e!di~P&HmOt/TO~P`Ow%]O!P'aX!e'aX!g'aXr'aXt'aX#p'aX'q'aX~PNfO!e'kO!g'kO!P(`ar(`at(`a~O`/XOb*qO~Ot/YO~P&MOOt/]O~O%X%vO%Z%xO!e%Wi!g%Wi#p%Wi#w%Wi$`%Wi$a%Wi$b%Wi$c%Wi$d%Wi%r%Wi%s%Wi%t%Wi'q%Wi!P%Wir%Wit%Wi#e%Wi~P&HmO%X%vO%Z%xO!e%Yi!g%Yi#p%Yi#w%Yi$`%Yi$a%Yi$b%Yi$c%Yi$d%Yi%r%Yi%s%Yi%t%Yi'q%Yi!P%Yir%Yit%Yi#e%Yi~P&HmOv$mOw$nO!Q$lO%^&[O%z&iO!R%]i!^%]i!e%]i!g%]i!o%]i!x%]i#T%]i#V%]i#X%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%[%]i%`%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!P%]ir%]it%]i#e%]i~O%_&[O~P'/yOv$mOw$nO!Q$lO%[%wO%z&iO#V'ma#p'ma%X'ma%Z'ma%b'ma%c'ma%d'ma%e'ma%f'ma%g'ma%h'ma%i'ma%j'ma%k'ma%l'ma%n'ma%o'ma%p'ma%q'ma%r'ma%s'ma%t'ma&|'ma'q'ma!P'mar'mat'ma#e'ma~O!R&^O!^&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O!e'ma!g'ma#w'ma$`'ma$a'ma$b'ma$c'ma$d'ma~P'3`Ov$mOw$nO!Q$lO%[%wO%c%zO%d%{O%e%|O%f%}O%z&iO#V'na#p'na%X'na%Z'na%g'na%h'na%i'na%j'na%k'na%l'na%n'na%o'na%p'na%q'na%r'na%s'na%t'na&|'na'q'na!P'nar'nat'na#e'na~O!R&^O!^&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O%b&OO!e'na!g'na#w'na$`'na$a'na$b'na$c'na$d'na~P'6uO%_%]i~P'/yOv$mOw$nO!Q$lO!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%z&iO!^%]i!e%]i!g%]i#V%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!P%]ir%]it%]i#e%]i~O!R%]i!o%]i%`%]i~P':cO!R&^O!o&^O%`&^O~P':cOv$mOw$nO!Q$lO!R&^O!^&_O!o&^O!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%z&iO!e%]i!g%]i#V%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!P%]ir%]it%]i#e%]i~O%g%]i%h%]i%i%]i%j%]i%k%]i~P'>VO%g&SO%h&QO%i&RO%j&`O%k&UO~P'>VOv$mOw$nO!Q$lO!R&^O!^&_O!o&^O!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%z&iO!e%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!P%]ir%]it%]i#e%]i~O#V%]i~P'BPO#V&WO~P'BPOv$mOw$nO!Q$lO!R&^O!^&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%z&iO!e%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!P%]ir%]it%]i#e%]i~O%o%]i~P'EmO%o&dO~P'EmOv$mOw$nO!Q$lO!R&^O!^&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%z&iO!e%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%r%]i%s%]i%t%]i'q%]i!P%]ir%]it%]i#e%]i~O%X%]i%Z%]i%q%]i&|%]i~P'IZO%X%vO%Z%xO%q&fO&|&jO~P'IZO%X%vO%Z%xO%r&XO!e%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%s%]i%t%]i'q%]i!P%]ir%]it%]i#e%]i~P&HmO#e/`O~P&MOO`/bO~O`/bO~P+vO`/bOa/cO~P+vO`/eO~Oc/gO'y/fO~O`/eO~P+vO`/eOa/hO~P+vOc/kO'y/jO~O!x/lO~P+vO`/mO~Oc/oO'y/nO~O`/mO~P+vO`/mOa/pO~P+vO^/rO'|$oO~O_+xO`+yO~O`/vOa/uO~P+vO_+xO`+yO~P+vO_+xO`+yOa/xO~P+vOa/{O~Ot/|O~P&MOOt/}O~P&MOOt0OO~P&MOO!e#ma!g#ma!x#ma#w#ma$`#ma$a#ma$b#ma$c#ma$d#ma%X#ma%Z#ma%[#ma%^#ma%_#ma%`#ma%a#ma%b#ma%c#ma%d#ma%e#ma%f#ma%g#ma%h#ma%i#ma%j#ma%k#ma%l#ma%n#ma%o#ma%p#ma%q#ma%r#ma%s#ma%t#ma&|#ma!P#mar#mat#ma#e#ma~P$+{Ot0PO~P&MOOQ]OjROkROlRO!Z0QO~O!e'kO!g'kO!P(pX~O!P0TO~Oo%TOw#ma#n#ma#p#ma'q#ma~Ow'yO#p'nO'q'oO~OQ#maR#maS#maT#maU#maj#mak#mal#map#max#maz#ma}#ma!O#ma!Q#ma!R#ma!S#ma!T#ma!V#ma!Z#ma![#ma!^#ma!`#ma!a#ma!b#ma!c#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%v#ma%w#ma%x#ma%z#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&R#ma&U#ma&V#ma&W#ma&X#ma&Y#ma&`#ma&b#ma&c#ma&d#ma&i#ma&j#ma&l#ma&x#ma&z#ma'O#ma'P#ma'Q#ma'S#ma'T#ma'V#ma'W#ma'X#ma'x#ma(T#ma(c#ma*l#ma!e#ma!g#ma~P('sO!e(za!g(za~P%2SOp'XO#t0^O~P%-]O!e'kO!g'kO#p)UX'q)UX~O!g0hO~O'r0jO's$iO't$jO~O!P0kO~O!P0lO~O!O(RO#e#daw#da#p#da'q#da~O!O0nO~Ow'yO#e-[O#p'nO'q'oO~Op-OO~O!e'kO!g'kO#w)[a$`)[a$a)[a$b)[a$c)[a$d)[a#p)[a'q)[a~O$g0uO$i0yOQ$eiR$eiS$eiT$eiU$eid$eij$eik$eil$eip$eiw$eix$eiz$ei}$ei!O$ei!Q$ei!R$ei!S$ei!T$ei!V$ei!Z$ei![$ei!^$ei!`$ei!a$ei!b$ei!c$ei!i$ei!l$ei!o$ei!t$ei!v$ei!z$ei!|$ei#O$ei#P$ei#R$ei#T$ei#V$ei#X$ei#[$ei#]$ei#^$ei#_$ei#a$ei#l$ei#p$ei#r$ei#s$ei#w$ei$Q$ei$Z$ei$_$ei$`$ei$a$ei$b$ei$c$ei$d$ei$w$ei$x$ei$y$ei$z$ei${$ei%Q$ei%R$ei%v$ei%w$ei%x$ei%z$ei%|$ei%}$ei&O$ei&P$ei&Q$ei&R$ei&U$ei&V$ei&W$ei&X$ei&Y$ei&`$ei&b$ei&c$ei&d$ei&i$ei&j$ei&l$ei&x$ei&z$ei'O$ei'P$ei'Q$ei'S$ei'T$ei'V$ei'W$ei'X$ei'p$ei'x$ei(T$ei(c$ei)k$ei*l$eit$ei%T$ei%U$ei%V$ei~O$g0uO$i0yOQ$jiR$jiS$jiT$jiU$jid$jij$jik$jil$jip$jiw$jix$jiz$ji}$ji!O$ji!Q$ji!R$ji!S$ji!T$ji!V$ji!Z$ji![$ji!^$ji!`$ji!a$ji!b$ji!c$ji!i$ji!l$ji!o$ji!t$ji!v$ji!z$ji!|$ji#O$ji#P$ji#R$ji#T$ji#V$ji#X$ji#[$ji#]$ji#^$ji#_$ji#a$ji#l$ji#p$ji#r$ji#s$ji#w$ji$Q$ji$Z$ji$_$ji$`$ji$a$ji$b$ji$c$ji$d$ji$w$ji$x$ji$y$ji$z$ji${$ji%Q$ji%R$ji%v$ji%w$ji%x$ji%z$ji%|$ji%}$ji&O$ji&P$ji&Q$ji&R$ji&U$ji&V$ji&W$ji&X$ji&Y$ji&`$ji&b$ji&c$ji&d$ji&i$ji&j$ji&l$ji&x$ji&z$ji'O$ji'P$ji'Q$ji'S$ji'T$ji'V$ji'W$ji'X$ji'p$ji'x$ji(T$ji(c$ji)k$ji*l$jit$ji%T$ji%U$ji%V$ji~O$n(aOQ$kiR$kiS$kiT$kiU$kid$kij$kik$kil$kip$kiw$kix$kiz$ki}$ki!O$ki!Q$ki!R$ki!S$ki!T$ki!V$ki!Z$ki![$ki!^$ki!`$ki!a$ki!b$ki!c$ki!i$ki!l$ki!o$ki!t$ki!v$ki!z$ki!|$ki#O$ki#P$ki#R$ki#T$ki#V$ki#X$ki#[$ki#]$ki#^$ki#_$ki#a$ki#l$ki#p$ki#r$ki#s$ki#w$ki$Q$ki$Z$ki$_$ki$`$ki$a$ki$b$ki$c$ki$d$ki$w$ki$x$ki$y$ki$z$ki${$ki%Q$ki%R$ki%v$ki%w$ki%x$ki%z$ki%|$ki%}$ki&O$ki&P$ki&Q$ki&R$ki&U$ki&V$ki&W$ki&X$ki&Y$ki&`$ki&b$ki&c$ki&d$ki&i$ki&j$ki&l$ki&x$ki&z$ki'O$ki'P$ki'Q$ki'S$ki'T$ki'V$ki'W$ki'X$ki'p$ki'x$ki(T$ki(c$ki)k$ki*l$kit$ki%T$ki%U$ki%V$ki~Oj1VO~Ol1VO#[!SO#]!TO#^!UO#_!VO~O#p'nO'q'oOQ$siR$siS$siT$siU$sid$sij$sik$sil$sip$siw$six$siz$si}$si!O$si!Q$si!R$si!S$si!T$si!V$si!Z$si![$si!^$si!`$si!a$si!b$si!c$si!i$si!l$si!o$si!t$si!v$si!z$si!|$si#O$si#P$si#R$si#T$si#V$si#X$si#[$si#]$si#^$si#_$si#a$si#l$si#p$si#r$si#s$si#w$si$Q$si$Z$si$_$si$`$si$a$si$b$si$c$si$d$si$w$si$x$si$y$si$z$si${$si%Q$si%R$si%v$si%w$si%x$si%z$si%|$si%}$si&O$si&P$si&Q$si&R$si&U$si&V$si&W$si&X$si&Y$si&`$si&b$si&c$si&d$si&i$si&j$si&l$si&x$si&z$si'O$si'P$si'Q$si'S$si'T$si'V$si'W$si'X$si'p$si'x$si(T$si(c$si)k$si*l$sit$si%T$si%U$si%V$si~O$n(aOQ$oiR$oiS$oiT$oiU$oid$oij$oik$oil$oip$oiw$oix$oiz$oi}$oi!O$oi!Q$oi!R$oi!S$oi!T$oi!V$oi!Z$oi![$oi!^$oi!`$oi!a$oi!b$oi!c$oi!i$oi!l$oi!o$oi!t$oi!v$oi!z$oi!|$oi#O$oi#P$oi#R$oi#T$oi#V$oi#X$oi#[$oi#]$oi#^$oi#_$oi#a$oi#l$oi#p$oi#r$oi#s$oi#w$oi$Q$oi$Z$oi$_$oi$`$oi$a$oi$b$oi$c$oi$d$oi$w$oi$x$oi$y$oi$z$oi${$oi%Q$oi%R$oi%v$oi%w$oi%x$oi%z$oi%|$oi%}$oi&O$oi&P$oi&Q$oi&R$oi&U$oi&V$oi&W$oi&X$oi&Y$oi&`$oi&b$oi&c$oi&d$oi&i$oi&j$oi&l$oi&x$oi&z$oi'O$oi'P$oi'Q$oi'S$oi'T$oi'V$oi'W$oi'X$oi'p$oi'x$oi(T$oi(c$oi)k$oi*l$oit$oi%T$oi%U$oi%V$oi~O#p'nO'q'oO~P$2PO$n(aOQ$qiR$qiS$qiT$qiU$qid$qij$qik$qil$qip$qiw$qix$qiz$qi}$qi!O$qi!Q$qi!R$qi!S$qi!T$qi!V$qi!Z$qi![$qi!^$qi!`$qi!a$qi!b$qi!c$qi!i$qi!l$qi!o$qi!t$qi!v$qi!z$qi!|$qi#O$qi#P$qi#R$qi#T$qi#V$qi#X$qi#[$qi#]$qi#^$qi#_$qi#a$qi#l$qi#p$qi#r$qi#s$qi#w$qi$Q$qi$Z$qi$_$qi$`$qi$a$qi$b$qi$c$qi$d$qi$w$qi$x$qi$y$qi$z$qi${$qi%Q$qi%R$qi%v$qi%w$qi%x$qi%z$qi%|$qi%}$qi&O$qi&P$qi&Q$qi&R$qi&U$qi&V$qi&W$qi&X$qi&Y$qi&`$qi&b$qi&c$qi&d$qi&i$qi&j$qi&l$qi&x$qi&z$qi'O$qi'P$qi'Q$qi'S$qi'T$qi'V$qi'W$qi'X$qi'p$qi'x$qi(T$qi(c$qi)k$qi*l$qit$qi%T$qi%U$qi%V$qi~Ol1VO~Ow%]Ov'aX!e'aX!g'aX!x'aX#p'aX#w'aX$`'aX$a'aX$b'aX$c'aX$d'aX%X'aX%Z'aX%['aX%^'aX%_'aX%`'aX%a'aX%b'aX%c'aX%d'aX%e'aX%f'aX%g'aX%h'aX%i'aX%j'aX%k'aX%l'aX%n'aX%o'aX%p'aX%q'aX%r'aX%s'aX%t'aX&|'aX'q'aX!P'aXr'aXt'aX#e'aX~PNfO!e'kO!g'kO#p(ya'q(ya!P(ya~Ov(yaw(ya!Q(ya!R(ya!^(ya!o(ya!x(ya#T(ya#V(ya#X(ya#w(ya$`(ya$a(ya$b(ya$c(ya$d(ya%X(ya%Z(ya%[(ya%^(ya%_(ya%`(ya%a(ya%b(ya%c(ya%d(ya%e(ya%f(ya%g(ya%h(ya%i(ya%j(ya%k(ya%l(ya%n(ya%o(ya%p(ya%q(ya%r(ya%s(ya%t(ya%z(ya&|(yar(yat(ya#e(ya~P)1QO!e'kO!g'kOv)WXw)WX!Q)WX!R)WX!^)WX!o)WX!x)WX#T)WX#V)WX#X)WX#p)WX#w)WX$`)WX$a)WX$b)WX$c)WX$d)WX%X)WX%Z)WX%[)WX%^)WX%_)WX%`)WX%a)WX%b)WX%c)WX%d)WX%e)WX%f)WX%g)WX%h)WX%i)WX%j)WX%k)WX%l)WX%n)WX%o)WX%p)WX%q)WX%r)WX%s)WX%t)WX%z)WX&|)WX'q)WX!P)WXr)WXt)WX#e)WX~O!P1bO!e'kO!g'kO~Ov$mOw$nO!Q$lO%z&iO!e*_a!g*_a!P*_a~O!R*_a!^*_a!o*_a!x*_a#T*_a#V*_a#X*_a#p*_a#w*_a$`*_a$a*_a$b*_a$c*_a$d*_a%X*_a%Z*_a%[*_a%^*_a%_*_a%`*_a%a*_a%b*_a%c*_a%d*_a%e*_a%f*_a%g*_a%h*_a%i*_a%j*_a%k*_a%l*_a%n*_a%o*_a%p*_a%q*_a%r*_a%s*_a%t*_a&|*_a'q*_ar*_at*_a#e*_a~P)8TOv(`aw(`a!Q(`a!R(`a!^(`a!o(`a!x(`a#T(`a#V(`a#X(`a#p(`a#w(`a$`(`a$a(`a$b(`a$c(`a$d(`a%X(`a%Z(`a%[(`a%^(`a%_(`a%`(`a%a(`a%b(`a%c(`a%d(`a%e(`a%f(`a%g(`a%h(`a%i(`a%j(`a%k(`a%l(`a%n(`a%o(`a%p(`a%q(`a%r(`a%s(`a%t(`a%z(`a&|(`a'q(`a#e(`a~P',dO!P1dO~Op5}Ot(`P~P#@SOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOv$mOw.SOxXOzSO}VO!O%ZO!Q.RO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$POo(OX!P(`P!e(OX!g(OX~O!x(OX%X(OX%Z(OX%[(OX%^(OX%_(OX%`(OX%a(OX%b(OX%c(OX%d(OX%e(OX%f(OX%g(OX%h(OX%i(OX%j(OX%k(OX%l(OX%n(OX%o(OX%p(OX%q(OX%r(OX%s(OX%t(OX&|(OX~P)>}O!P1iO~Oj1jOp)ZO~O!P1mO~O!P1nO~Ot1oO~P&MOO!e'kO!g'kOr*^Xv*^Xw*^X!Q*^X!R*^X!^*^X!o*^X!x*^X#T*^X#V*^X#X*^X%X*^X%Z*^X%[*^X%^*^X%_*^X%`*^X%a*^X%b*^X%c*^X%d*^X%e*^X%f*^X%g*^X%h*^X%i*^X%j*^X%k*^X%l*^X%n*^X%o*^X%p*^X%q*^X%r*^X%s*^X%t*^X%z*^X&|*^Xt*^X#e*^X#p*^X'q*^X!P*^X~Or1pO~P&MOOo%TOt1qO!e5]Oj&oXp&oXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROt1qO~P&MOOp)xO~Og1sO'|$oO~Og.mO'|$oO^(Si~O`1uOa*PO~OP1vOp1vO~Oj1wOxYOzSO}VO(TUO~Ot1xO~Op1yO~P'(eOw1{O!Q1|O~O!S1}O~Oj2OOxYOzSO}VO!R2PO!S2OO!T2OO(TUO~Or2QO~OP2ROp2RO~O`2TO~P+vO!P'aa!e'aa!g'aar'aat'aa#p'aa#w'aa$`'aa$a'aa$b'aa$c'aa$d'aa'q'aa#e'aa~P%2SOv!niv!nqw!niw!nq!Q!ni!Q!nq!R!ni!R!nq!^!ni!^!nq!e!ni!e!nq!g!ni!g!nq!o!ni!o!nq!x!ni!x!nq#T!ni#T!nq#V!ni#V!nq#X!ni#X!nq#p!ni#p!nq#w!ni#w!nq$`!ni$`!nq$a!ni$a!nq$b!ni$b!nq$c!ni$c!nq$d!ni$d!nq%X!ni%X!nq%Z!ni%Z!nq%[!ni%[!nq%^!ni%^!nq%_!ni%_!nq%`!ni%`!nq%a!ni%a!nq%b!ni%b!nq%c!ni%c!nq%d!ni%d!nq%e!ni%e!nq%f!ni%f!nq%g!ni%g!nq%h!ni%h!nq%i!ni%i!nq%j!ni%j!nq%k!ni%k!nq%l!ni%l!nq%n!ni%n!nq%o!ni%o!nq%p!ni%p!nq%q!ni%q!nq%r!ni%r!nq%s!ni%s!nq%t!ni%t!nq%z!ni%z!nq&|!ni&|!nq'q!ni'q!nq!P!ni!P!nqr!nir!nqt!nit!nq#e!ni#e!nq~O%X%vO%Z%xO!e%Yq!g%Yq#p%Yq#w%Yq$`%Yq$a%Yq$b%Yq$c%Yq$d%Yq%r%Yq%s%Yq%t%Yq'q%Yq!P%Yqr%Yqt%Yq#e%Yq~P&HmO!e&{q!g&{q#p&{q#w&{q$`&{q$a&{q$b&{q$c&{q$d&{q%X&{q%Z&{q%r&{q%s&{q%t&{q'q&{q!P&{qr&{qt&{q#e&{q~P&HmO`2XO~O`2XO~P+vOc2ZO'y2YO~O`2[O~O`2[O~P+vO'y2]O~Oc2^O'y2]O~Oc2`O'y2_O~O`2aO~O`2aO~P+vO^2bO~O`2dOa2cO~P+vO`2dO~Oc2gO'y2fO~O`2dO~P+vOa2iO~O!P2kO~O!P'cX!e'cX!g'cX~P$NrO!e'kO!g'kO!P(pa~O!e'kO!g'kO#n2wO#p'nO'q'oO~P$:cO!P2yO~O!O,qO!e'hX!g'hX#p'hX'q'hX~P%-]O!e'kO!g'kO#p)Ua'q)Ua~O!O,qO!iiO#p)UP'q)UP~P%-]O!P,{O#c,|O~O$g0uO$i0yOQ$eqR$eqS$eqT$eqU$eqd$eqj$eqk$eql$eqp$eqw$eqx$eqz$eq}$eq!O$eq!Q$eq!R$eq!S$eq!T$eq!V$eq!Z$eq![$eq!^$eq!`$eq!a$eq!b$eq!c$eq!i$eq!l$eq!o$eq!t$eq!v$eq!z$eq!|$eq#O$eq#P$eq#R$eq#T$eq#V$eq#X$eq#[$eq#]$eq#^$eq#_$eq#a$eq#l$eq#p$eq#r$eq#s$eq#w$eq$Q$eq$Z$eq$_$eq$`$eq$a$eq$b$eq$c$eq$d$eq$w$eq$x$eq$y$eq$z$eq${$eq%Q$eq%R$eq%v$eq%w$eq%x$eq%z$eq%|$eq%}$eq&O$eq&P$eq&Q$eq&R$eq&U$eq&V$eq&W$eq&X$eq&Y$eq&`$eq&b$eq&c$eq&d$eq&i$eq&j$eq&l$eq&x$eq&z$eq'O$eq'P$eq'Q$eq'S$eq'T$eq'V$eq'W$eq'X$eq'p$eq'x$eq(T$eq(c$eq)k$eq*l$eqt$eq%T$eq%U$eq%V$eq~O$g0uO$i0yOQ$jqR$jqS$jqT$jqU$jqd$jqj$jqk$jql$jqp$jqw$jqx$jqz$jq}$jq!O$jq!Q$jq!R$jq!S$jq!T$jq!V$jq!Z$jq![$jq!^$jq!`$jq!a$jq!b$jq!c$jq!i$jq!l$jq!o$jq!t$jq!v$jq!z$jq!|$jq#O$jq#P$jq#R$jq#T$jq#V$jq#X$jq#[$jq#]$jq#^$jq#_$jq#a$jq#l$jq#p$jq#r$jq#s$jq#w$jq$Q$jq$Z$jq$_$jq$`$jq$a$jq$b$jq$c$jq$d$jq$w$jq$x$jq$y$jq$z$jq${$jq%Q$jq%R$jq%v$jq%w$jq%x$jq%z$jq%|$jq%}$jq&O$jq&P$jq&Q$jq&R$jq&U$jq&V$jq&W$jq&X$jq&Y$jq&`$jq&b$jq&c$jq&d$jq&i$jq&j$jq&l$jq&x$jq&z$jq'O$jq'P$jq'Q$jq'S$jq'T$jq'V$jq'W$jq'X$jq'p$jq'x$jq(T$jq(c$jq)k$jq*l$jqt$jq%T$jq%U$jq%V$jq~O$n(aOQ$kqR$kqS$kqT$kqU$kqd$kqj$kqk$kql$kqp$kqw$kqx$kqz$kq}$kq!O$kq!Q$kq!R$kq!S$kq!T$kq!V$kq!Z$kq![$kq!^$kq!`$kq!a$kq!b$kq!c$kq!i$kq!l$kq!o$kq!t$kq!v$kq!z$kq!|$kq#O$kq#P$kq#R$kq#T$kq#V$kq#X$kq#[$kq#]$kq#^$kq#_$kq#a$kq#l$kq#p$kq#r$kq#s$kq#w$kq$Q$kq$Z$kq$_$kq$`$kq$a$kq$b$kq$c$kq$d$kq$w$kq$x$kq$y$kq$z$kq${$kq%Q$kq%R$kq%v$kq%w$kq%x$kq%z$kq%|$kq%}$kq&O$kq&P$kq&Q$kq&R$kq&U$kq&V$kq&W$kq&X$kq&Y$kq&`$kq&b$kq&c$kq&d$kq&i$kq&j$kq&l$kq&x$kq&z$kq'O$kq'P$kq'Q$kq'S$kq'T$kq'V$kq'W$kq'X$kq'p$kq'x$kq(T$kq(c$kq)k$kq*l$kqt$kq%T$kq%U$kq%V$kq~O$n(aOQ$oqR$oqS$oqT$oqU$oqd$oqj$oqk$oql$oqp$oqw$oqx$oqz$oq}$oq!O$oq!Q$oq!R$oq!S$oq!T$oq!V$oq!Z$oq![$oq!^$oq!`$oq!a$oq!b$oq!c$oq!i$oq!l$oq!o$oq!t$oq!v$oq!z$oq!|$oq#O$oq#P$oq#R$oq#T$oq#V$oq#X$oq#[$oq#]$oq#^$oq#_$oq#a$oq#l$oq#p$oq#r$oq#s$oq#w$oq$Q$oq$Z$oq$_$oq$`$oq$a$oq$b$oq$c$oq$d$oq$w$oq$x$oq$y$oq$z$oq${$oq%Q$oq%R$oq%v$oq%w$oq%x$oq%z$oq%|$oq%}$oq&O$oq&P$oq&Q$oq&R$oq&U$oq&V$oq&W$oq&X$oq&Y$oq&`$oq&b$oq&c$oq&d$oq&i$oq&j$oq&l$oq&x$oq&z$oq'O$oq'P$oq'Q$oq'S$oq'T$oq'V$oq'W$oq'X$oq'p$oq'x$oq(T$oq(c$oq)k$oq*l$oqt$oq%T$oq%U$oq%V$oq~O$n(aOQ$qqR$qqS$qqT$qqU$qqd$qqj$qqk$qql$qqp$qqw$qqx$qqz$qq}$qq!O$qq!Q$qq!R$qq!S$qq!T$qq!V$qq!Z$qq![$qq!^$qq!`$qq!a$qq!b$qq!c$qq!i$qq!l$qq!o$qq!t$qq!v$qq!z$qq!|$qq#O$qq#P$qq#R$qq#T$qq#V$qq#X$qq#[$qq#]$qq#^$qq#_$qq#a$qq#l$qq#p$qq#r$qq#s$qq#w$qq$Q$qq$Z$qq$_$qq$`$qq$a$qq$b$qq$c$qq$d$qq$w$qq$x$qq$y$qq$z$qq${$qq%Q$qq%R$qq%v$qq%w$qq%x$qq%z$qq%|$qq%}$qq&O$qq&P$qq&Q$qq&R$qq&U$qq&V$qq&W$qq&X$qq&Y$qq&`$qq&b$qq&c$qq&d$qq&i$qq&j$qq&l$qq&x$qq&z$qq'O$qq'P$qq'Q$qq'S$qq'T$qq'V$qq'W$qq'X$qq'p$qq'x$qq(T$qq(c$qq)k$qq*l$qqt$qq%T$qq%U$qq%V$qq~Ol3]O~O!P3_O~Ov'iX!e'iX!g'iX!x'iX#p'iX#w'iX$`'iX$a'iX$b'iX$c'iX$d'iX%X'iX%Z'iX%['iX%^'iX%_'iX%`'iX%a'iX%b'iX%c'iX%d'iX%e'iX%f'iX%g'iX%h'iX%i'iX%j'iX%k'iX%l'iX%n'iX%o'iX%p'iX%q'iX%r'iX%s'iX%t'iX&|'iX'q'iX!P'iXr'iXt'iX#e'iX~P!-}O!e'kO!g'kOv)Waw)Wa!Q)Wa!R)Wa!^)Wa!o)Wa!x)Wa#T)Wa#V)Wa#X)Wa#p)Wa#w)Wa$`)Wa$a)Wa$b)Wa$c)Wa$d)Wa%X)Wa%Z)Wa%[)Wa%^)Wa%_)Wa%`)Wa%a)Wa%b)Wa%c)Wa%d)Wa%e)Wa%f)Wa%g)Wa%h)Wa%i)Wa%j)Wa%k)Wa%l)Wa%n)Wa%o)Wa%p)Wa%q)Wa%r)Wa%s)Wa%t)Wa%z)Wa&|)Wa'q)Wa!P)War)Wat)Wa#e)Wa~Ot3`O~Ov$mOw$nO!Q$lO!R*^i!^*^i!e*^i!g*^i!o*^i!x*^i#T*^i#V*^i#X*^i#p*^i#w*^i$`*^i$a*^i$b*^i$c*^i$d*^i%X*^i%Z*^i%[*^i%^*^i%_*^i%`*^i%a*^i%b*^i%c*^i%d*^i%e*^i%f*^i%g*^i%h*^i%i*^i%j*^i%k*^i%l*^i%n*^i%o*^i%p*^i%q*^i%r*^i%s*^i%t*^i%z*^i&|*^i'q*^i!P*^ir*^it*^i#e*^i~O!P3bO~O!e'kO!g'kOr(`X~P%2SO!e'kO!g'kOt(`X~P%2SO!P3cO~O!O(ROv&nqw&nq!Q&nq!R&nq!^&nq!e&nq!g&nq!o&nq!x&nq#T&nq#V&nq#X&nq#p&nq#w&nq$`&nq$a&nq$b&nq$c&nq$d&nq%X&nq%Z&nq%[&nq%^&nq%_&nq%`&nq%a&nq%b&nq%c&nq%d&nq%e&nq%f&nq%g&nq%h&nq%i&nq%j&nq%k&nq%l&nq%n&nq%o&nq%p&nq%q&nq%r&nq%s&nq%t&nq%z&nq&|&nq'q&nq!P&nqr&nqt&nq#e&nq~O!O(ROv&kyw&ky!Q&ky!R&ky!^&ky!e&ky!g&ky!o&ky!x&ky#T&ky#V&ky#X&ky#p&ky#w&ky$`&ky$a&ky$b&ky$c&ky$d&ky%X&ky%Z&ky%[&ky%^&ky%_&ky%`&ky%a&ky%b&ky%c&ky%d&ky%e&ky%f&ky%g&ky%h&ky%i&ky%j&ky%k&ky%l&ky%n&ky%o&ky%p&ky%q&ky%r&ky%s&ky%t&ky%z&ky&|&ky'q&ky!P&kyr&kyt&ky#e&ky~O!P3iO~Ot3jO~Or3kO~Op3lO~P'(eO!P3nO~O!S3oO~Ov!fiw!fi!Q!fi!R!fi!^!fi!o!fi!x!fi#T!fi#V!fi#X!fi%X!fi%Z!fi%[!fi%^!fi%_!fi%`!fi%a!fi%b!fi%c!fi%d!fi%e!fi%f!fi%g!fi%h!fi%i!fi%j!fi%k!fi%l!fi%n!fi%o!fi%p!fi%q!fi%r!fi%s!fi%t!fi%z!fi&|!fi~O!e!fi!g!fi#p#gi'q#gi!P#gi~P+8[O!e&{y!g&{y#p&{y#w&{y$`&{y$a&{y$b&{y$c&{y$d&{y%X&{y%Z&{y%r&{y%s&{y%t&{y'q&{y!P&{yr&{yt&{y#e&{y~P&HmO'y3pO~Oc3qO'y3pO~O'y3rO~O'y3sO~Oc3tO'y3sO~O`3uO~Oc3wO'y3vO~O`3uO~P+vO`3uOa3xO~P+vO`3zO~Oa3{O~O!e'kO!g'kO#p'nO'q'oO~P$:cO#p'nO'q'oO~P&MOO!P4XO~O$n(aOQ$qyR$qyS$qyT$qyU$qyd$qyj$qyk$qyl$qyp$qyw$qyx$qyz$qy}$qy!O$qy!Q$qy!R$qy!S$qy!T$qy!V$qy!Z$qy![$qy!^$qy!`$qy!a$qy!b$qy!c$qy!i$qy!l$qy!o$qy!t$qy!v$qy!z$qy!|$qy#O$qy#P$qy#R$qy#T$qy#V$qy#X$qy#[$qy#]$qy#^$qy#_$qy#a$qy#l$qy#p$qy#r$qy#s$qy#w$qy$Q$qy$Z$qy$_$qy$`$qy$a$qy$b$qy$c$qy$d$qy$w$qy$x$qy$y$qy$z$qy${$qy%Q$qy%R$qy%v$qy%w$qy%x$qy%z$qy%|$qy%}$qy&O$qy&P$qy&Q$qy&R$qy&U$qy&V$qy&W$qy&X$qy&Y$qy&`$qy&b$qy&c$qy&d$qy&i$qy&j$qy&l$qy&x$qy&z$qy'O$qy'P$qy'Q$qy'S$qy'T$qy'V$qy'W$qy'X$qy'p$qy'x$qy(T$qy(c$qy)k$qy*l$qyt$qy%T$qy%U$qy%V$qy~O!P4_O~P&MOO!P4`O~Or*civ*ciw*ci!Q*ci!R*ci!^*ci!e!fi!g!fi!o*ci!x*ci#T*ci#V*ci#X*ci%X*ci%Z*ci%[*ci%^*ci%_*ci%`*ci%a*ci%b*ci%c*ci%d*ci%e*ci%f*ci%g*ci%h*ci%i*ci%j*ci%k*ci%l*ci%n*ci%o*ci%p*ci%q*ci%r*ci%s*ci%t*ci%z*ci&|*cit*ci#e*ci#p*ci'q*ci!P*ci~Or*jiv*jiw*ji!Q*ji!R*ji!^*ji!e!fi!g!fi!o*ji!x*ji#T*ji#V*ji#X*ji%X*ji%Z*ji%[*ji%^*ji%_*ji%`*ji%a*ji%b*ji%c*ji%d*ji%e*ji%f*ji%g*ji%h*ji%i*ji%j*ji%k*ji%l*ji%n*ji%o*ji%p*ji%q*ji%r*ji%s*ji%t*ji%z*ji&|*jit*ji#e*ji#p*ji'q*ji!P*ji~Ot4aO~Or4bO~O!P4cO~O'y4dO~O'y4eO~Oc4gO'y4fO~O`4hO~O`4hO~P+vOc4jO'y4iO~O`4kO~O$n(aOQ$q!RR$q!RS$q!RT$q!RU$q!Rd$q!Rj$q!Rk$q!Rl$q!Rp$q!Rw$q!Rx$q!Rz$q!R}$q!R!O$q!R!Q$q!R!R$q!R!S$q!R!T$q!R!V$q!R!Z$q!R![$q!R!^$q!R!`$q!R!a$q!R!b$q!R!c$q!R!i$q!R!l$q!R!o$q!R!t$q!R!v$q!R!z$q!R!|$q!R#O$q!R#P$q!R#R$q!R#T$q!R#V$q!R#X$q!R#[$q!R#]$q!R#^$q!R#_$q!R#a$q!R#l$q!R#p$q!R#r$q!R#s$q!R#w$q!R$Q$q!R$Z$q!R$_$q!R$`$q!R$a$q!R$b$q!R$c$q!R$d$q!R$w$q!R$x$q!R$y$q!R$z$q!R${$q!R%Q$q!R%R$q!R%v$q!R%w$q!R%x$q!R%z$q!R%|$q!R%}$q!R&O$q!R&P$q!R&Q$q!R&R$q!R&U$q!R&V$q!R&W$q!R&X$q!R&Y$q!R&`$q!R&b$q!R&c$q!R&d$q!R&i$q!R&j$q!R&l$q!R&x$q!R&z$q!R'O$q!R'P$q!R'Q$q!R'S$q!R'T$q!R'V$q!R'W$q!R'X$q!R'p$q!R'x$q!R(T$q!R(c$q!R)k$q!R*l$q!Rt$q!R%T$q!R%U$q!R%V$q!R~O'y4uO~Oc4vO'y4uO~O'y4wO~Oc4xO'y4wO~O$n(aOQ$q!ZR$q!ZS$q!ZT$q!ZU$q!Zd$q!Zj$q!Zk$q!Zl$q!Zp$q!Zw$q!Zx$q!Zz$q!Z}$q!Z!O$q!Z!Q$q!Z!R$q!Z!S$q!Z!T$q!Z!V$q!Z!Z$q!Z![$q!Z!^$q!Z!`$q!Z!a$q!Z!b$q!Z!c$q!Z!i$q!Z!l$q!Z!o$q!Z!t$q!Z!v$q!Z!z$q!Z!|$q!Z#O$q!Z#P$q!Z#R$q!Z#T$q!Z#V$q!Z#X$q!Z#[$q!Z#]$q!Z#^$q!Z#_$q!Z#a$q!Z#l$q!Z#p$q!Z#r$q!Z#s$q!Z#w$q!Z$Q$q!Z$Z$q!Z$_$q!Z$`$q!Z$a$q!Z$b$q!Z$c$q!Z$d$q!Z$w$q!Z$x$q!Z$y$q!Z$z$q!Z${$q!Z%Q$q!Z%R$q!Z%v$q!Z%w$q!Z%x$q!Z%z$q!Z%|$q!Z%}$q!Z&O$q!Z&P$q!Z&Q$q!Z&R$q!Z&U$q!Z&V$q!Z&W$q!Z&X$q!Z&Y$q!Z&`$q!Z&b$q!Z&c$q!Z&d$q!Z&i$q!Z&j$q!Z&l$q!Z&x$q!Z&z$q!Z'O$q!Z'P$q!Z'Q$q!Z'S$q!Z'T$q!Z'V$q!Z'W$q!Z'X$q!Z'p$q!Z'x$q!Z(T$q!Z(c$q!Z)k$q!Z*l$q!Zt$q!Z%T$q!Z%U$q!Z%V$q!Z~O!P4}O~P&MOO'y5OO~O'y5PO~O!P5QO~P&MOOj&xOw&yO!V5ZO~OR6sOS7POT5VOp5^O!R5[O![6oO!o6pO%v5[O%w5[O%z6rO~P#/zOR6sOS7POT5VOp5^O!R5[O![6oO!o6pO%v5[O%w5[O%z6rO~P#8OOp5{O~P$!SOj)nOw)oO!V5ZO~Oo%TO!e5]Oj&oXp&oXr#YXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YXt#YX#e#YX#p#YX'q#YX!P#YX~P!NRO#p(`X#w(`X$`(`X$a(`X$b(`X$c(`X$d(`X'q(`Xr(`Xt(`X#e(`X~P$2PO%X6SO~P#JWOr%]av%]aw%]a!Q%]a!R%]a!^%]a!o%]a!x%]a#T%]a#V%]a#X%]a%X%]a%Z%]a%[%]a%^%]a%_%]a%`%]a%a%]a%j%]a%k%]a%l%]a%n%]a%o%]a%p%]a%q%]a%r%]a%s%]a%t%]a%z%]a&|%]at%]a#e%]a#p%]a'q%]a!P%]a~O%b5cO%c%zO%d%{O%e%|O%f%}O%g%]a%h%]a%i%]a~P,4XO%g5eO%h&QO%i&RO%b%]a%c%]a%d%]a%e%]a%f%]a~P,4XOv$mOw$nO!Q$lO!R)XX!^)XX!e)XX!g)XX!o)XX!x)XX#T)XX#V)XX#X)XX#p)XX#w)XX$`)XX$a)XX$b)XX$c)XX$d)XX%X)XX%Z)XX%[)XX%^)XX%_)XX%`)XX%a)XX%b)XX%c)XX%d)XX%e)XX%f)XX%g)XX%h)XX%i)XX%j)XX%k)XX%l)XX%n)XX%o)XX%p)XX%q)XX%r)XX%s)XX%t)XX%z)XX&|)XX'q)XX!P)XXr)XXt)XX#e)XX~Ov$mOw$nO!Q$lO!R5iO!^5jO!o5iO!x5hO#T5hO#V&WO#X5hO%X5`O%Z5aO%[%wO%^5gO%_5gO%`5iO%a5jO%b5cO%c%zO%d%{O%e%|O%f%}O%g5eO%h&QO%i&RO%j5kO%k&UO%l&VO%n5nO%o5oO%p5pO%q5qO%z&iO&|6vO~Or%ua%r%ua%s%ua%t%uat%ua#e%ua#p%ua'q%ua!P%ua~P,;TO!e'kO!g'kO#p(yX'q(yX!P(yX~P%2SOv$mOw$nO!Q$lOQ*gXR*gXS*gXT*gXU*gXj*gXk*gXl*gXo(OXp*gXx*gXz*gX}*gX!O*gX!P(OX!P*gX!R(OX!R*gX!S*gX!T*gX!V*gX!Z*gX![*gX!^(OX!^*gX!`*gX!a*gX!b*gX!c*gX!e(OX!g(OX!i*gX!l*gX!o(OX!o*gX!t*gX!v*gX!x(OX!z*gX!|*gX#O*gX#P*gX#R*gX#T(OX#T*gX#V(OX#V*gX#X(OX#X*gX#[*gX#]*gX#^*gX#_*gX#a*gX%X(OX%Z(OX%[(OX%^(OX%_(OX%`(OX%a(OX%b(OX%c(OX%d(OX%e(OX%f(OX%g(OX%h(OX%i(OX%j(OX%k(OX%l(OX%n(OX%o(OX%p(OX%q(OX%r(OX%s(OX%t(OX%v*gX%w*gX%x*gX%z(OX%z*gX%|*gX%}*gX&O*gX&P*gX&Q*gX&R*gX&U*gX&V*gX&W*gX&X*gX&Y*gX&`*gX&b*gX&c*gX&d*gX&i*gX&j*gX&l*gX&x*gX&z*gX&|(OX'O*gX'P*gX'Q*gX'S*gX'T*gX'V*gX'W*gX'X*gX'x*gX(T*gX(c*gX*l*gX~Or(OXr*gX!x*gX%X*gX%Z*gX%[*gX%^*gX%_*gX%`*gX%a*gX%b*gX%c*gX%d*gX%e*gX%f*gX%g*gX%h*gX%i*gX%j*gX%k*gX%l*gX%n*gX%o*gX%p*gX%q*gX%r*gX%s*gX%t*gX&|*gXt(OXt*gX#e(OX#e*gX#p(OX#p*gX'q(OX'q*gX~P,>eOr(`P!x(`P%X(`P%Z(`P%[(`P%^(`P%_(`P%`(`P%a(`P%b(`P%c(`P%d(`P%e(`P%f(`P%g(`P%h(`P%i(`P%j(`P%k(`P%l(`P%n(`P%o(`P%p(`P%q(`P%r(`P%s(`P%t(`P&|(`Pt(`P#e(`P#p(`P'q(`P~P)>}O!R5iO!^5jO!o5iO!x5hO#T5hO#X5hO%^5gO%_5gO%`5iO%a5jO%b5cO%g5eO%j5kO~P&<tO!e5]O~P&@`Ov$mOw$nO!Q$lO!R5iO!^5jO!o5iO!x5hO#T5hO#V&WO#X5hO%[%wO%^5gO%_5gO%`5iO%a5jO%b5cO%c%zO%d%{O%e%|O%f%}O%g5eO%h&QO%i&RO%j5kO%k&UO%l&VO%n5nO%o5oO%p5pO%q5qO%z&iO&|6vO~Or&ya%X&ya%Z&ya%r&ya%s&ya%t&yat&ya#e&ya#p&ya'q&ya!P&ya~P,LSOo%TOt.kO!e%SOj&oXp&oXv#mXw&rX!g#YX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROr!di%r!di%s!di%t!dit!di#e!di#p!di'q!di!P!di~P,;TOr%Wi%r%Wi%s%Wi%t%Wit%Wi#e%Wi#p%Wi'q%Wi!P%Wi~P,;TOr%Yi%r%Yi%s%Yi%t%Yit%Yi#e%Yi#p%Yi'q%Yi!P%Yi~P,;TOv$mOw$nO!Q$lO%^5gO%z&iOr%]i!R%]i!^%]i!o%]i!x%]i#T%]i#V%]i#X%]i%X%]i%Z%]i%[%]i%`%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!P%]i~O%_5gO~P-%cO!R5iO!^5jO!o5iO!x5hO#T5hO#X5hO%^5gO%_5gO%`5iO%a5jO~P'3`O!R5iO!^5jO!o5iO!x5hO#T5hO#X5hO%^5gO%_5gO%`5iO%a5jO%b5cO~P'6uO%_%]i~P-%cOv$mOw$nO!Q$lO!x5hO#T5hO#X5hO%[%wO%^5gO%_5gO%z&iOr%]i!^%]i#V%]i%X%]i%Z%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!P%]i~O!R%]i!o%]i%`%]i~P-*QO!R5iO!o5iO%`5iO~P-*QOv$mOw$nO!Q$lO!R5iO!^5jO!o5iO!x5hO#T5hO#X5hO%[%wO%^5gO%_5gO%`5iO%a5jO%b5cO%c%zO%d%{O%e%|O%f%}O%z&iOr%]i#V%]i%X%]i%Z%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!P%]i~O%g%]i%h%]i%i%]i%j%]i%k%]i~P--[O%g5eO%h&QO%i&RO%j5kO%k&UO~P--[Ov$mOw$nO!Q$lO!R5iO!^5jO!o5iO!x5hO#T5hO#X5hO%[%wO%^5gO%_5gO%`5iO%a5jO%b5cO%c%zO%d%{O%e%|O%f%}O%g5eO%h&QO%i&RO%j5kO%k&UO%l&VO%z&iOr%]i%X%]i%Z%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!P%]i~O#V%]i~P-0lO#V&WO~P-0lOv$mOw$nO!Q$lO!R5iO!^5jO!o5iO!x5hO#T5hO#V&WO#X5hO%[%wO%^5gO%_5gO%`5iO%a5jO%b5cO%c%zO%d%{O%e%|O%f%}O%g5eO%h&QO%i&RO%j5kO%k&UO%l&VO%n5nO%z&iOr%]i%X%]i%Z%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!P%]i~O%o%]i~P-3pO%o5oO~P-3pOv$mOw$nO!Q$lO!R5iO!^5jO!o5iO!x5hO#T5hO#V&WO#X5hO%[%wO%^5gO%_5gO%`5iO%a5jO%b5cO%c%zO%d%{O%e%|O%f%}O%g5eO%h&QO%i&RO%j5kO%k&UO%l&VO%n5nO%o5oO%p5pO%z&iOr%]i%r%]i%s%]i%t%]it%]i#e%]i#p%]i'q%]i!P%]i~O%X%]i%Z%]i%q%]i&|%]i~P-6tO%X5`O%Z5aO%q5qO&|6vO~P-6tO%r&XOr%]i%s%]i%t%]it%]i#e%]i#p%]i'q%]i!P%]i~P,;TO!P2VO~O!P*_a!e*_a!g*_a~P%2SO!P3fO~O!P3gO~Or%Yq%r%Yq%s%Yq%t%Yqt%Yq#e%Yq#p%Yq'q%Yq!P%Yq~P,;TOr&{q%X&{q%Z&{q%r&{q%s&{q%t&{qt&{q#e&{q#p&{q'q&{q!P&{q~P,LSO!e#gi!g#gi~P+8[Or#giv#giw#gi!Q#gi!R#gi!^#gi!e!fi!g!fi!o#gi!x#gi#T#gi#V#gi#X#gi%X#gi%Z#gi%[#gi%^#gi%_#gi%`#gi%a#gi%b#gi%c#gi%d#gi%e#gi%f#gi%g#gi%h#gi%i#gi%j#gi%k#gi%l#gi%n#gi%o#gi%p#gi%q#gi%r#gi%s#gi%t#gi%z#gi&|#git#gi#e#gi#p#gi'q#gi!P#gi~Or&{y%X&{y%Z&{y%r&{y%s&{y%t&{yt&{y#e&{y#p&{y'q&{y!P&{y~P,LSO!e5]O~P?lOQ]OR6sOS7POT5VOU$OOjQOkROlROp5^OxXOzSO}VO!O%ZO!QmO!R5[O!S$eO!T$eO!V$fO!Z$eO![6oO!^^O!``O!aaO!bbO!ccO!iiO!llO!o6pO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5[O%w5[O%x#XO%z6rO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~Ow%rO~P-@}OQ]OR6sOS7POT5VOU$OOjQOkROlROp5^Ow%]OxXOzSO}VO!QmO!R5[O!S$eO!T$eO!V$fO!Z$eO![6oO!^^O!``O!aaO!bbO!ccO!iiO!llO!o6pO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5[O%w5[O%x#XO%z6rO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~O!OhOr&SXv&SX!x&SX%X&SX%Z&SX%[&SX%^&SX%_&SX%`&SX%a&SX%b&SX%c&SX%d&SX%e&SX%f&SX%g&SX%h&SX%i&SX%j&SX%k&SX%l&SX%n&SX%o&SX%p&SX%q&SX%r&SX%s&SX%t&SX&|&SXt&SX#e&SX#p&SX'q&SX!P&SX~P-F_OQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$POr(`Pv(`Pw(`P!Q(`P!R(`P!o(`P!x(`P#T(`P#V(`P#X(`P%X(`P%Z(`P%[(`P%^(`P%_(`P%`(`P%a(`P%b(`P%c(`P%d(`P%e(`P%f(`P%g(`P%h(`P%i(`P%j(`P%k(`P%l(`P%n(`P%o(`P%p(`P%q(`P%r(`P%s(`P%t(`P%z(`P&|(`Pt(`P#e(`P#p(`P'q(`P!P(`P~Oj5xOp({O!O6yO&e(}O&f)OO&g)PO~P-MyOj5yOp%XO!O6zO~P-MyO#e6cO~P#JWO#e6jO~P&MOO!O7TO~P%'sO!P6mO~O!P6lO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!O7TO!QmO!R#YO!S$eO!T$eO!V$fO!Z$eO![gO!^^O!``O!aaO!bbO!ccO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(TUO(cqO*l$PO~OwnO~P.)UOk7SO!O)fO#R!OO~O#tx#n!T!S%wp![jkl!Z#c!l%Z%`%z!l!R!o%^!V#R#T#V#X!x!Q%^~",
  goto: "&1x*}PPPPPPPPPPPPPPPPPPPPPPPP+O+OPPP+{,qPP-gP-jP-jPPP.`P.`.`PPPPPPP1xP6]9j<wPP<zP@[PPPP@[PCdPFnPJO@[PJUMcP@[@[@[@[P@[P@[P@[P@[P@[PP!!sP!'WP@[P@[P!*f@[PPPPJUP!-qP!.OP!.i!/a!1xP!2Z!5cP!5lP!9[P!5cPPP!:g!5cP!5cP!5cP!5cP!5c!5cP!5cP!5cPPP!5c!5cP!;]!5c!;cPPPPPP!5c!;pP!;vP!5c!5c!<S!<]P!5c!5c!5cP!5c!5c!=O!5cPPPPP!5c!5c!5c!5cPP!=XPPP@[P@[PP@[PPPPPPPPPPPPPPP!=^PPPPPPP@[PPP@[P@[PPPPPP@[@[PPPPP@[!>q@[!A{@[P@[PPPPPP@[PP@[P!ET@[!E[@[@[!Hg@[@[@[!Ko@[P@[P@[P@[PPP@[PP@[PPPP!Ny#!c#!i#!|##S##^##e##|#$S#$Y#%Z#%b#&O#&U#&[#&j#&t#'Q#'W#(y#*hPPPPPPPPPPPPP#*n#+d#/i#/r#3d#6|P#7i#;R#;[#BU#Ei#IV#IV#IV#L_$ g$$s$&[$'lP$*x$.Q$1Y$4b$7j$7|$7|$;U$>l$>l$>l$>l$Ax$A{$BR$Ed$Eg$Et$E}$IS$I]$If$Ix$I|$Jd$Jg$Jk$Jq$Ju$KO$KR$KRIx$KU$K]$Ki$LY$Lc$Ll$Lo$L|$M`$Mu$N[$N[$Nq$Nw$N}% [% [% [% [% [P% h% h% q% v% v% v% {%#p%#p%#p%#p%%a%%a%&|%(g%)|%*u%*u%+l%.v%.v%.v%.v%.v%.v%2O%5Y%5Y%5Y%5Y%5Y%8b%;l%;p%;y%;y%;y%?T%?X%?X%?X%?b%?j%?j%Bt%BxP%FU%I`%Lj& t& t& t&$|&%Q&(Y&(Y&+b&+e&.m&.m&.m&1uQ$kP!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3yT,x'n,y!g$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3y!g$tUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3yR2S/O!g$wUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3y'}YOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*V*Y*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.].u.w.x.|/`0^0b0e0h1Z1^1c1l1{1|2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3yS&x!O5TQ&z!PQ&|!QQ'Q!RS)n$f5ZT)y$m$|'g]Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,X,c-f-u-y-z.P.R.S.U.W.]/`0R0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U'g[Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,X,c-f-u-y-z.P.R.S.U.W.]/`0R0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UR*d%P'm_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.]/`0^0b0e0h1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U'akOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U'`kOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ,s'hR2|0hQ%ajR*t%b'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UV(u#q(w5U'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UU(u#q(w5UR,o'e'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3yQ)e$ZQ)h$_Q)k$dQ.^)fQ._)iQ.`)lR7S7V'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ)k$dR.`)l'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UR,n'eS'{!g%_Q-W'wQ0W,[R0o-Q!P't!g%_'u'w'{'},[-T-U-W-Y-]-_0U0W0Y0q0s0t2o2p2r3}S'|!g%_S-S'u'}Q-X'wU0X,[-U-YQ0m-OS0r-T-_U2n0U0Y0tQ2}0qS4O2o2rR4l3}t'r!g%_'u'w'},[-O-T-U-Y-_0U0Y0q0t2o2r3}Q(S!qQ(T!rQ(U!sQ(Z!uQ(]!vW(q#k#l7P7QS(s#n7RS)y$m$|Q*e%RQ+P%tQ,b'YQ,e'ZQ-d(VQ-e(WS-g(X(^Q.X)[Q.i)yQ0],cQ1U-hS1k.]6|Q2u0^Q3P0vQ3[1VQ3d1jQ3e1lQ3h1rS4Q2v2wQ4[3]R4o4RS'}!g%_Q-T'uQ-Y'wS0Y,[-UR2o0U^!wOn$h%W%p'y*kS'z!g%_Q(Y!tQ(h#PU(r#l#|7QW)Q#u(|6t6yS)X#x6uS)a$Q5WS)b$S5XQ,^'WQ-V'wQ-Z'xS-^'{'|Q-a(SQ-b(TQ-c(UQ-m(ZQ-p(]Q-r(bS.W)V6zU0V,[-W-XQ0Z,_S0p-S-]Q1P-dQ1Q-eQ1T-gU2q0W0X0sQ3O0rQ3S0zQ3Z1US3|2n2pQ4U2}Q4V3PQ4Z3[Q4^3_Q4m4OQ4q4XQ4s4[Q4y4lQ5R4}R5S5Q_#WOn$h%W%p'y*k'[#mOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ'P!QQ'W![S'Y!_!`Q'j!cQ)[#zQ0^,fR1j.Z#c'o!e!w!y%i%m%u'W'Y'b'c'j'w(Y([(d*i*z*{,[,_,b,c,g,i,k,o,s-W-X-f-l-n-o/[0W0X0]0^0s1R1S2n2p2u2v2w2x2|3^4O4Q4R4W4l4oW(q#k#l7P7QS(s#n7RQ+P%tQ,b'YQ0],cS1k.]6|Q2u0^Q3e1lS4Q2v2wR4o4RQ'w!gR,['US!pO$hU%in%p'yT*i%W*kX0w-a-b0x0|Q0{-aQ0}-bQ3R0xR3T0|_!tOn$h%W%p'y*kQ(d!wQ-l(YQ1O-cQ1Y-mQ1]-pQ3U1PQ3V1QQ3Y1TQ4Y3ZQ4r4ZR4|4s_!yOn$h%W%p'y*kV%nn%p'y![&bp%Y%e%g(O(k(o)d*f+R+S+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6f!c5m)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5u5|6O6P6Q6]6^6_6`6a6b6i6k6n6{%S#nOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X7R$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6v']#oOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7US)y$m$|R1r.j'[#zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UR.Z)]']#|Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U%S$QOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X5W$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6vQ$vUQ&lqQ)s$jr*]$v&l)s*_+l+p+s+v+|/Q/d/i/q/w/y2e3yQ*_$zQ+l&mQ+p&oQ+s&qQ+v&rQ+|&tQ/Q*`Q/d+mQ/i+qQ/q+wQ/w+{Q/y+}Q2e/tR3y2hQ*U$sR.s*Ub$pTWjsuxz}+yS)}$p.lT.l*O.nQ.n*OR1t.nQ*Q$qS.o*Q.qR.q*SS%OZ,VR*b%O[*n%Y%e-n1R1f1gQ-v(oQ-}5_W/V*n-v-}/^R/^5vQ*r%`R/W*rQ0S,YR2m0SS'u!g%_f-R'u-U-]-_0U0q0s0t2p2r3}Q-U'wQ-]'{Q-_'}Q0U,[Q0q-TQ0s-WQ0t-YQ2p0WQ2r0YR3}2oS%pn'yR*|%pd%Uf%X'i({)c){.g5^5{5}W*h%U,T,],`S,T'O)ZQ,]'VR,`'XQ,y'nR0i,yQ0f,rR2{0fQ'm!dU,w'm-`1_Q-`(PR1_-wQ0x-aQ0|-bT3Q0x0|^!xOn$h%W%p'y*kR(f!xQ*k%WR/S*k!f&Pp%Y%e%g(O(k(o)^)d*f+R+S+X+^+_+`+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6fS+W&P5d!m5d)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5u5z5|6O6P6Q6U6Y6Z6[6]6^6_6`6a6b6i6k6n6{!b&Tp%Y%e%g(O(k(o)^)d*f+R+S+_+`+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6fS+Y&T5f!i5f)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5u5z5|6O6P6Q6Z6[6]6^6_6`6a6b6i6k6n6{Q$hOR)p$h!g$yUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3y'`ZOhmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}/Q/d/i/q/t/w/y2e2h3yV,V'S,X0RQ.v*VQ1y.wR3l1{'l_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.]/`0^0b0e0h1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UU.t*V.w1{U.z*Y.x1|Q1w.uR2O.|'}TOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*V*Y*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.].u.w.x.|/`0^0b0e0h1Z1^1c1l1{1|2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ$rTQ${WQ%bjQ&nsQ&puQ&sxQ&uzQ&w}R/s+y'}WOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*V*Y*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.].u.w.x.|/`0^0b0e0h1Z1^1c1l1{1|2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ.}*YQ1z.xR3m1|[pO$h%W%p'y*kQ%Yhr%em%Z%]%r'q(R(|)V-y.P.U.W6w6y6z7T7UQ%gnW%so#Y5[6pS(O!j'lQ(k#ZS(l#[6r`(o#k#l#n.]6|7P7Q7RQ)^#}Q)d$UQ)u$lQ)|$nQ*f%SQ*u%dQ+R%vQ+S%xS+T%y&]Q+V&OQ+X&SQ+Z&[Q+[&^Q+]&_Q+^&`Q+_&aQ+`&bQ+a&cQ+b&dQ+c&eQ+d&fQ+e&gQ+f&hQ+g&jQ,Q&yQ,R&{Q,S&}Q,U'RQ,d'ZQ-n([Q-|(yQ.a)oQ.f)vQ.h)wS/U*m-uQ/_+UQ/a+hQ1R-fS1a-z6eQ1f.RQ1g.SQ2W/`Q2x0bQ3^1ZQ3a1cQ4W3WQ4t4]Q4{4p`5_#u#x)T)U)X5y6t6u`5t#d$Q$S(r1^5W5X6sQ5u6q`5v%t'Y,c0^1l2v2w4RQ5z5VQ5|5YQ6O5]Q6P5`Q6Q5aS6R5b5hQ6T5cQ6U5eQ6V5gQ6W5iQ6X5jQ6Y5kQ6Z5lQ6[5mQ6]5nQ6^5oQ6_5pQ6`5qQ6a5rQ6b5sQ6f6xQ6i6SQ6k6cQ6n6jR6{6v'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7US'T!X%^S,W'S0RR0Q,X'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ,g'^Q,k'bQ,n'eU,p'h0e0hQ0^,fR0d,q']dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UT,h'`'bS%[h%ZS%fm.RU%hn%].SS)R#u6tS)W#x6uQ+O%rW,}'q(R([-fQ.O(|Q.Q)TU.T)U)X5yQ.V)VQ1`-yQ1e.PS1h.U.WQ6d6wQ6g6yQ6h6zQ6}7TR7O7UW'l!d'm(P-`b*m%Y%e*n-n/^1R1f1g5vQ,f'[W-u(o-v-}5_Q.])eS0R,Y0SQ0b,nS0e,r0fS1^-w1_Q1c-{Q1l.^Q2v0^Q4R2wQ6e.eR6|7S'ejOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b0h1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']sOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ+{&tU/t+z+|+}Q/z,OS2h/x/yR2j/{']}Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U^!XOn$h%W%p'y*k&|%^hmo!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q(R([(r(y(|)T)U)V)X)o)v)w*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UQ(_!vQ-i(XQ-q(`R1W-j'e!WOhmno!j!v#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R(X([(`(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-j-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UR,Z'SQ,Y'SR2l0R^!gOn$h%W%p'y*k'S%_hmo!j#Y#Z#[#d#k#l#n#q#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q(R([(r(w(y(|)T)U)V)X)o)v)w*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5U5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UT'U!X!hR-Q'sS$gO$hU%on%p'yT*j%W*k_![On$h%W%p'y*kQ'p!eQ(c!wQ(g!yQ*x%iQ*y%mQ+Q%uQ,^'WQ,a'YQ,j'bQ,l'cQ,u'jQ-V'wS-k(Y(dQ-o([Q/R*iS/Z*z*{U0V,[-W-XQ0Z,_S0[,b,cQ0_,gQ0`,iQ0a,kQ0c,oQ0g,sQ1S-fQ1X-lQ1Z-nQ1[-oQ2U/[U2q0W0X0sQ2s0]Q2t0^Q3W1RQ3X1SS3|2n2pU4P2u2v2wQ4S2xQ4T2|Q4]3^Q4m4OS4n4Q4RQ4p4WQ4y4lR4z4o_!_On$h%W%p'y*k_!`On$h%W%p'y*kq(p#k#l#n%t'Y,c.]0^1l2v2w4R6|7P7Q7RT'[!_!`^!qOn$h%W%p'y*k^%tp!p%g%i%m*i*{T'Z!_!`R'^!_T'`!_!`Q,i'`R,k'bT'b!_!`_!cOn$h%W%p'y*kR'e!_R'h!_S,r'h0hR2z0e^!eOn$h%W%p'y*kR-x(r^!dOn$h%W%p'y*kQ(P!jS(n#d6sS)a$Q5WS)b$S5XS,v'l1^R-w(r_!hOn$h%W%p'y*k_!jOn$h%W%p'y*kR(Q!jY%up!p%g%i*iQ*z%mR/[*{^!rOn$h%W%p'y*k_%tp!p%g%i%m*i*{^!sOn$h%W%p'y*k^%tp!p%g%i%m*i*{R(V!t^!uOn$h%W%p'y*k^%tp!p%g%i%m*i*{R(W!t^!vOn$h%W%p'y*k^%tp!p%g%i%m*i*{R(X!tX0v-a-b0x0|X0z-a-b0x0|g(b!w(Y-c-m-p1P1Q1T3Z4Z4s^#POn$h%W%p'y*kR'x!g_#VOn$h%W%p'y*kV%on%p'yV%mn%p'y!l%yp%Y%e%g(O(k(o)^)d*f+R+S+V+X+[+]+^+_+`+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6f!s5b)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5u5z5|6O6P6Q6T6U6W6X6Y6Z6[6]6^6_6`6a6b6i6k6n6{!h&Op%Y%e%g&P(O(k(o)^)d*f+R+S+X+^+_+`+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6f!o5c)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5d5u5z5|6O6P6Q6U6Y6Z6[6]6^6_6`6a6b6i6k6n6{!d&Sp%Y%e%g&T(O(k(o)^)d*f+R+S+_+`+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6f!k5e)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5f5u5z5|6O6P6Q6Z6[6]6^6_6`6a6b6i6k6n6{!b&`p%Y%e%g(O(k(o)^)d*f+R+S+_+`+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6f!i5k)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5u5z5|6O6P6Q6Z6[6]6^6_6`6a6b6i6k6n6{!^&ap%Y%e%g(O(k(o)d*f+R+S+`+a+b+c+d+e+f,d-n/U/_/a1R1f1g2W5_5v6f!e5l)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{5u5|6O6P6Q6[6]6^6_6`6a6b6i6k6n6{p&gp%Y%e%g(O(o+f,d-n/U1R1f1g5_5v6fw5r)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{6b6{n&hp%Y%e%g(O(o,d-n/U1R1f1g5_5v6fu5s)u)|*u+g,Q,R,S,U.a.f.h2x3^3a4W4t4{6{%S#ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X6q$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6v']#cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U%S#lOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X7Q$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6v']#jOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U%S#qOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X5U$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6vT(x#q5UQ(v#qQ-{(wR.e5U%S#uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X6t$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6vT)S#u6tW)Q#u(|6t6yR)`$OS)T#u6tT.P(|6y%S#xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X6u$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6vT)Y#x6u'[#{Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UT)z$m$|%S$SOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X5X$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6v%S$UOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X5Y$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6v%S$ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^1^1l2v2w4R5y6t6u6w6x6y6z6|7P7Q7R7T7U#X7V$l$n%d&j&y&{&}'R)o)v)w0b1Z1c3W4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s6S6c6e6j6p6q6r6s6v']$YOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UT)g$Z7V']$_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']$^Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UR)j$_']$dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7U']$cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/`0^0b1Z1^1c1l2v2w3W4R4]4p5V5W5X5Y5[5]5`5a5b5c5e5g5h5i5j5k5l5m5n5o5p5q5r5s5y6S6c6e6j6p6q6r6s6t6u6v6w6x6y6z6|7P7Q7R7T7UR)m$d",
  nodeNames: "⚠ UnrestrictedIdentifier SpecialScalarVariable NamedUnaryOperator ListOperator FileTestOp IOOperatorStart Glob ReadonlySTDIN IOOperatorEnd HeredocStartIdentifier HeredocEndIdentifier InterpolatedStringContent EscapeSequence QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter QuoteLikeEndDelimiter StringContent QWElement RegexOptions PodDirective PodContent PodCut Comment UninterpolatedHeredocBody InterpolatedHeredocBody ScalarVariable ArrayVariable HashVariable PackageVariable PackageName :: Identifier PackageVariableName ] ArrayAccessVariable } HashAccessVariable ArrowOperator { StringSingleQuoted StringQQuoted q StringDoubleQuoted StringQqQuoted qq ( ) [ ArithOp Integer Float ScalarDereference $ PackageVariable PackageName PackageVariableName TypeGlob Option HeredocInitializer << SpecialLiteral __FILE__ __LINE__ __PACKAGE__ __SUB__ Pair FatComma List Comma QWList qw QWListContent ArrayLength $# ArrayRef HashRef ArithOp ArrayAccessVariable HashAccessVariable BacktickQuoted CommandQxQuoted qx PatternMatchM m PatternMatch / RegexQr qr SubstitutionS s TransliterationTrOrY tr y ArrayDereference @ HashDereference % FunctionDereference & TypeGlobDereference * Constant VariableDeclaration our state my local AnonymousFunction sub FunctionPrototype Prototype FunctionAttribute : FunctionSignature ParenthesizedArguments FunctionPrototypeAttribute prototype Block PackageStatement package PackageName Version StatementEnd ; UseNoStatement use no ModuleName Arguments UseNoIfStatement if UseLibStatement lib UseNoSubsStatement subs UseNoFeatureStatement feature UseNoVersion RequireStatement require UseConstantStatement constant UseParentOrBaseStatement parent base NoRequire ExpressionStatement FunctionDefinition async FunctionName SingleLineStatement ReturnExpression return unless while until for foreach IfStatement ElsifClause elsif ElseClause else UnlessStatement WhileStatement Label Continue continue UntilStatement ForStatement1 ForStatement2 \\ StandaloneBlock NamedBlockStatement NamedBlock SpecialBlock BEGIN UNITCHECK CHECK INIT END Ellipsis EmptyStatement PodStatement EndDataStatement __END__ __DATA__ LoopControlStatement next last redo Assignment = UpdateExpression UpdateOp x BinaryExpression ArithOp BindingOp ConcatOp BitOp CompareOp lt gt le ge CompareOp eq ne CompareOp cmp isa BitOp BitOp LogicOp LogicOp RangeOp and or xor UnaryExpression LogicOp RefOp not UpdateExpression ArithOp NoArgumentNamedUnaryOperator fork getpid time times wait wantarray NamedUnaryExpression ListOperatorExpression grep map join sort unpack CallExpression FunctionName CallExpressionWithBareword FunctionName Bless bless OutputFunction print say printf STDIN STDERR STDOUT SystemCall exec system MethodInvocation SUPER FunctionName IndirectMethodInvocation FunctionName CallExpressionRecursive ArrayFunction FunctionName FileTest IOOperator EvalExpression Eval DoExpression do GotoExpression goto TernaryExpression LogicOp ArrayModifierFunction push unshift splice ArrayPopOrShift pop shift HashOrArrayDestructureFunction each values keys Program",
  maxTerm: 458,
  context: contextTracker,
  nodeProps: [
    ["group", -64,2,26,27,28,40,41,43,44,50,51,52,54,57,58,59,61,66,68,70,73,75,76,78,79,80,81,83,85,87,89,91,94,96,98,100,102,103,108,192,194,197,221,225,227,234,235,241,243,245,247,254,257,260,262,263,265,266,267,269,271,273,275,279,282,"Expression",-26,119,125,130,132,134,136,138,139,141,143,147,148,151,159,164,165,169,170,171,173,174,176,182,183,184,185,"Statement"],
    ["closedBy", 6,"IOOperatorEnd",39,"}",46,")",48,"]"],
    ["openedBy", 9,"IOOperatorStart",34,"[",36,"{",47,"("],
    ["isolate", -2,23,40,""]
  ],
  skippedNodes: [0],
  repeatNodeCount: 21,
  tokenData: "!.V~RzXY#uYZ#u]^#upq#uqr#zrs$ast'qtu(Yuv,[vw/xwx1uxy<^yz<cz{<h{|AV|}Bv}!OB{!O!PHj!P!QKd!Q!RKw!R![M_![!]! }!]!^!![!^!_!#R!_!`!#s!`!a!$W!a!b!$p!b!c!$u!c!}!(f!}#O!(w#O#P!)n#P#Q!*g#Q#R!+^#R#S!+i#S#T!,P#T#j!(f#j#k!,U#k#o!(f#o#p!-]#p#q!-b#q#r!-p#r#s!-u~#zO'|~~$PQ%v~!_!`$V#r#s$[~$[O%g~~$aO%_~~$fU(T~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~${UOY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~%bWOY$xZ!O$x!O!P%_!P#d$x#d#e%z#e;'S$x;'S;=`'k<%lO$x~%}WOY$xZ!O$x!O!P%_!P#a$x#a#b&g#b;'S$x;'S;=`'k<%lO$x~&jWOY$xZr$xrs'Ss!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'XU#t~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'nP;=`<%l$x~'vSg~OY'qZ;'S'q;'S;=`(S<%lO'q~(VP;=`<%l'q~(a_#c`!V~st)`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!c!}*Y!}#O)e#O#P)e#P#Q)e#R#S*Y#T#o*Y#o#p*k~)eO!l~`)jY#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~*_Sj~!Q![*Y!c!}*Y#R#S*Y#T#o*Y~*nVXY*kYZ*k]^*kpq*k!c!}+T#R#S+T#T#o+T~+WXXY+sYZ+s]^+spq+s!Q![+T!c!}+T#R#S+T#T#o+T#q#r,V~+vTXY+sYZ+s]^+spq+s#q#r,V~,[Oj~~,ca#c`#T~qr-htu)euv)evw)ez{)e{|-m}!O-h!Q![.d!]!^)e!_!`.u!b!c)e!c!}.d!}#O)e#O#P.z#P#Q)e#R#S.d#T#o.d~-mOl~~-tYl~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~.iSl~!Q![.d!c!}.d#R#S.d#T#o.d~.zO%Z~~/PZ#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R/r~/uP!c!}-h~0P[#c`#V~tu)euv)evw0uz{)e{|)e!O!P1o!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~0|Z%oQ#c`tu)euv)evw)ez{)e{|)e!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~1rP!_!`.u~1zZx~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P;'S1u;'S;=`<W<%lO1u~2rVx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X<%lO2m~3^Ox~~3aRO;'S2m;'S;=`3j;=`O2m~3oWx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X;=`<%l2m<%lO2m~4[P;=`<%l2m~4dUx~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~4yUOY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~5`WOY4vZ!O4v!O!P5]!P#d4v#d#e5x#e;'S4v;'S;=`7i<%lO4v~5{WOY4vZ!O4v!O!P5]!P#a4v#a#b6e#b;'S4v;'S;=`7i<%lO4v~6hWOY4vZw4vwx7Qx!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~7VU#t~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~7lP;=`<%l4v~7t]x~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P#d1u#d#e9w#e;'S1u;'S;=`<W<%lO1u~8pWOY1uYZ2mZ!O1u!O!P7o!P;'S1u;'S;=`9Y;=`<%l2m<%lO1u~9_Wx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X;=`<%l1u<%lO2m~9|]x~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P#a1u#a#b:u#b;'S1u;'S;=`<W<%lO1u~:zZx~OY1uYZ2mZw1uwx;mx!O1u!O!P7o!P#O1u#O#P8m#P;'S1u;'S;=`<W<%lO1u~;tU#t~x~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~<ZP;=`<%l1u~<cO!O~~<hO!P~~<o_#c`#X~tu)euv)evw)ez{=n{|)e!]!^)e!_!`.u!b!c)e!c!}>h!}#O)e#O#P)e#P#Q)e#R#S>h#T#o>h#o#p?c~=uZ#c`%^~tu)euv)evw)ez{)e{|)e!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~>mT!Z~!Q![>h![!]>|!c!}>h#R#S>h#T#o>h~?PP![!]?S~?VS!c!}>h#R#S>h#T#o>h#o#p?c~?fVXY?cYZ?c]^?cpq?c!c!}?{#R#S?{#T#o?{~@OXXY@kYZ@k]^@kpq@k!Q![?{!c!}?{#R#S?{#T#o?{#q#r@}~@nTXY@kYZ@k]^@kpq@k#q#r@}~ASP!Z~![!]>|~A^Z#c`!o~tu)euv)evw)ez{)e{|BP!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~BWY#c`%z~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~B{O!g~~CQW!Rk}!OCj!_!`.u!`!aCo!c!}Ct#R#SCt#T#bCt#b#cDV#c#oCt~CoO%z~~CtOv~kCyS![k!Q![Ct!c!}Ct#R#SCt#T#oCtoD[U![k!Q![Ct!c!}Ct#R#SCt#T#cCt#c#dDn#d#oCtoDsU![k!Q![Ct!c!}Ct#R#SCt#T#fCt#f#gEV#g#oCtoE[U![k!Q![Ct!c!}Ct#R#SCt#T#XCt#X#YEn#Y#oCtoEsU![k!Q![Ct!c!}Ct#R#SCt#T#eCt#e#fFV#f#oCtoF[U![k!Q![Ct!c!}Ct#R#SCt#T#iCt#i#jFn#j#oCtoFsU![k!Q![Ct!c!}Ct#R#SCt#T#]Ct#]#^GV#^#oCtoG[U![k!Q![Ct!c!}Ct#R#SCt#T#fCt#f#gGn#g#oCtoGsU![k!Q![Ct!c!}Ct#R#SCt#T#XCt#X#YHV#Y#oCtoH^S$WS![k!Q![Ct!c!}Ct#R#SCt#T#oCt~HqS#n[%`Q!O!PH}!Q![JP!_!`.u#R#SIq_IUR%qQ#n[!O!PI_!Q![Iq#R#SIq_IhR)kP%qQ#n[!O!PIq!Q![Iq#R#SIq[IvR#n[!O!PIq!Q![Iq#R#SIq~JWT#n[!T~!O!PIq!Q![JP!g!hJg#R#SKU#X#YJg~JjR{|Js}!OJs!Q![Jy~JvP!Q![Jy~KOQ!T~!Q![Jy#R#SJs~KZR#n[!O!PIq!Q![JP#R#SIq~KiQ!x~!P!QKo!_!`.u~KtP%p~!_!`.u~LO[#n[!S~!O!PJP!Q!YLt!Y![M_!d!eNf!g!hJg!q!rN}!z!{! `#R#SMu#U#VNf#X#YJg#c#dN}#l#m! `~L{U#n[!S~!O!PJP!Q!YLt!Y![M_!g!hJg#R#SNT#X#YJg~MfT#n[!S~!O!PJP!Q![M_!g!hJg#R#SMu#X#YJg~MzR#n[!O!PIq!Q![M_#R#SIq~NYS#n[!O!PIq!Q!YLt!Y![M_#R#SIq~NiQ!Q!RNo!R!SNo~NtR!S~!Q!RNo!R!SNo#R#SNf~! QP!Q!Y! T~! YQ!S~!Q!Y! T#R#SN}~! cR!Q![! l!c!i! l#T#Z! l~! qS!S~!Q![! l!c!i! l#R#S! `#T#Z! l~!!SP#e~![!]!!V~!![Oo~o!!cY#p_#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!#WQ%b~!^!_!#^!_!`!#f~!#cP!^~!_!`.u~!#kP%b~!`!a!#n~!#sO%j~~!#xR%X~!_!`$V!`!a!$R#r#s$[~!$WO!e~~!$]Q%b~!_!`!$c!`!a!$h~!$hO%b~~!$mP%a~!_!`.u~!$uO&|~~!$|c#c`#R~qr!&Xtu)euv)evw)ez{)e{|!&^|!Q!&X!Q![!'T![!]!&X!]!^!&^!^!b!&X!b!c!&^!c!}!'T!}#O!&^#O#P!'f#P#Q!&^#Q#R!&X#R#S!'T#T#o!'T~!&^Ok~~!&eYk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!'YSk~!Q![!'T!c!}!'T#R#S!'T#T#o!'T~!'mZk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R!(`~!(cP!c!}!&X~!(kSp~!Q![!(f!c!}!(f#R#S!(f#T#o!(f~!)OY#c`!Q~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)eo!)wY$rS%wk#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)ec!*nYrR#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!+cQ%n~!O!P1o!_!`.u~!+pT#n[p~!O!PIq!Q![!+i!c!}!(f#R#S!+i#T#o!(f~!,UO(c~~!,ZTp~!O!P!,j!Q![!,u!c!}!(f#R#S!(f#T#o!(f[!,oQ#n[!O!P!,j!Q![!,j~!,|T#n[p~!O!P!,j!Q![!,u!c!}!(f#R#S!(f#T#o!(f~!-bOw~~!-gR%n~!O!P1o!_!`.u#p#qKo~!-uOt~~!-zQ%v~!O!P!.Q#r#s!#n~!.VO%v~",
  tokenizers: [semicolon, unrestrictedIdentifier, specialScalarVariable, builtinOperator, fileIO, heredoc, interpolated, quoteLikeOperator, regex, pod, endData, 0, 1, 2, 3, 4],
  topRules: {"Program":[0,286]},
  dynamicPrecedences: {"152":1,"185":4,"268":1,"322":1,"325":1,"328":1,"333":1,"334":1,"335":1,"336":1,"340":1,"342":1,"343":1,"344":1,"345":1,"347":1,"348":1,"350":1,"351":1,"352":1,"353":1,"356":1,"357":1,"359":1,"361":1,"362":1,"365":1,"366":1,"367":1,"369":1,"370":1,"371":1,"372":1,"373":1,"378":1,"379":1,"382":1,"383":1,"384":1,"385":1,"386":1,"387":1,"388":1,"389":1,"390":1,"391":1,"392":1,"393":1,"394":1,"396":1,"397":1,"399":1,"400":1,"401":1,"402":1,"403":1,"404":1,"405":1,"406":1,"407":1,"408":1,"409":1,"410":1,"411":1,"412":1,"413":1,"414":1,"415":1,"416":1,"417":1,"418":1,"419":1,"420":1,"422":1,"423":1,"424":1,"425":1,"426":1,"427":1,"430":1,"431":1,"432":1,"434":1,"435":1,"436":1,"438":1,"439":1,"441":1,"443":1,"444":1,"445":1,"446":1,"447":1,"448":1,"450":1,"451":1,"452":1,"454":1,"455":1,"456":1,"457":1},
  specialized: [{term: 32, get: (value) => spec_Identifier[value] || -1}],
  tokenPrec: 28139
});

const perlLanguage = language.LRLanguage.define({
    name: 'perl',
    parser: parser.configure({
        props: [
            language.indentNodeProp.add({
                IfStatement: language.continuedIndent({ except: /^\s*({|else\b|elsif\b)/ }),
                Block: language.delimitedIndent({ closing: '}' }),
                'StringSingleQuoted StringQQuoted StringDoubleQuoted StringQqQuoted QWList': () => null,
                'StatementEnd InterpolatedHeredocBody UninterpolatedHeredocBody': () => null,
                Statement: language.continuedIndent()
            }),
            language.foldNodeProp.add({
                'Block Array ArrayRef HashRef': language.foldInside,
                'InterpolatedHeredocBody UninterpolatedHeredocBody': (node) => {
                    if (node.prevSibling && node.lastChild)
                        return { from: node.prevSibling.to, to: node.lastChild.from };
                    return null;
                },
                PodStatement(node) {
                    if (node.firstChild?.type.name === 'PodDirective' &&
                        node.firstChild.nextSibling?.type.name === 'PodContent')
                        return { from: node.firstChild.nextSibling.from, to: node.firstChild.nextSibling.to };
                    return null;
                },
                EndDataStatement: (node) => (node.firstChild ? { from: node.firstChild.to, to: node.to } : null)
            }),
            highlight.styleTags({
                'do continue else elsif for foreach goto if last next redo return unless until when while': highlight.tags.controlKeyword,
                'bless local my our state sub': highlight.tags.definitionKeyword,
                'package use no import require parent base': highlight.tags.moduleKeyword,
                'constant feature lib subs async prototype': highlight.tags.modifier,
                'NamedUnaryOperator ListOperator Eval each exec fork getpid grep': highlight.tags.function(highlight.tags.keyword),
                'join keys map pop print printf push say shift sort splice system time times': highlight.tags.function(highlight.tags.keyword),
                'unpack unshift values wait wantarray': highlight.tags.function(highlight.tags.keyword),
                'BEGIN CHECK END INIT UNITCHECK': highlight.tags.processingInstruction,
                '__FILE__ __LINE__ __PACKAGE__ __SUB__': highlight.tags.literal,
                'ScalarVariable SpecialScalarVariable ArrayVariable HashVariable': highlight.tags.variableName,
                'ArrayLength/Identifier Prototype Constant/Identifier': highlight.tags.variableName,
                'PackageVariable/PackageVariableName/...': highlight.tags.variableName,
                'PackageName/Identifier PackageName/UnrestrictedIdentifier PackageName/ScalarVariable': highlight.tags.namespace,
                'PackageName/ArrayVariable PackageName/HashVariable SUPER': highlight.tags.namespace,
                'NamedType/...': highlight.tags.typeName,
                Name: highlight.tags.name,
                'Label/Identifier LabelName/Identifier STDIN STDERR STDOUT IOOperator/Identifier': highlight.tags.labelName,
                'MemberExpression/Identifier': highlight.tags.propertyName,
                'MemberExpression/ScalarVariable': highlight.tags.special(highlight.tags.propertyName),
                'FunctionName/PackageName/... FunctionName/Identifier': highlight.tags.function(highlight.tags.definition(highlight.tags.variableName)),
                UpdateOp: highlight.tags.updateOperator,
                'ArithOp "*" % "/"': highlight.tags.arithmeticOperator,
                'LogicOp and not or xor : FileTestOp': highlight.tags.logicOperator,
                BitOp: highlight.tags.bitwiseOperator,
                '<<': highlight.tags.special(highlight.tags.bitwiseOperator),
                'CompareOp < lt gt le ge eq ne cmp isa': highlight.tags.compareOperator,
                '=': highlight.tags.definitionOperator,
                '$ $# @ % & "*" ArrowOperator \\': highlight.tags.derefOperator,
                'ScalarDereference/{ ScalarDereference/}': highlight.tags.derefOperator,
                'ArrayDereference/{ ArrayDereference/}': highlight.tags.derefOperator,
                'HashDereference/{ HashDereference/}': highlight.tags.derefOperator,
                'FunctionDereference/{ FunctionDereference/}': highlight.tags.derefOperator,
                'TypeGlobDereference/{ TypeGlobDereference/}': highlight.tags.derefOperator,
                'ConcatOp BindingOp RangeOp RefOp x': highlight.tags.operator,
                Comment: highlight.tags.lineComment,
                Integer: highlight.tags.integer,
                Float: highlight.tags.float,
                'StringSingleQuoted StringDoubleQuoted q qq qx */StringContent */InterpolatedStringContent': highlight.tags.string,
                '*/QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter */QuoteLikeEndDelimiter': highlight.tags.string,
                'qw QWListContent/... Pair/Identifier HashAccessVariable/Identifier Version': highlight.tags.string,
                'HeredocInitializer/... HeredocEndIdentifier Glob': highlight.tags.string,
                'm qr s tr y RegexOptions': highlight.tags.special(highlight.tags.string),
                'PodStatement EndDataStatement/...': highlight.tags.blockComment,
                EscapeSequence: highlight.tags.escape,
                'Comma FatComma': highlight.tags.punctuation,
                '( )': highlight.tags.paren,
                '[ ]': highlight.tags.squareBracket,
                '{ }': highlight.tags.brace,
                '; :: :': highlight.tags.separator
            })
        ]
    }),
    languageData: { commentTokens: { line: '#' } }
});
const perlCompletion = perlLanguage.data.of({
    autocomplete: autocomplete.completeFromList([
        { label: 'my', type: 'keyword' },
        { label: 'use', type: 'keyword' },
        { label: 'sub', type: 'keyword' }
    ])
});
const perl = () => new language.LanguageSupport(perlLanguage, [perlCompletion]);

exports.perl = perl;
exports.perlCompletion = perlCompletion;
exports.perlLanguage = perlLanguage;
